<?php
// phpcs:ignore
/**
 * Description: Getting Maxboxy options form the Mataboxes
 */

if (! defined('ABSPATH')) { 
    exit; 
}

if (! class_exists('Max_Boxy_Options')) {

    // phpcs:ignore
    class Max_Boxy_Options
    {

        /**
         * Loading options.
         *
         * @param int $get_id Receive the id of the panel.
         * 
         * @return array.
         */
        public static function loading( $get_id )
        {

            $asign_metabox = get_post_type($get_id) === 'float_any'
                          || get_post_type($get_id) === 'inject_any'
                           ? true : false;

            if ($asign_metabox === false) {
                return;
            }

             /*
              * *_loading Meta box's data is unserialized, so get it directly
              * without the prefix, i.e. not using _mb_floatany like 
              * _mb_floatany_loading | _mb_injectany_loading.
              * ...Just use its fields directly, e.g. 'location' (location is under 
              * _loading mtabox as well)
              */
             $global_loading  = get_post_meta($get_id, 'auto_loading', true);
             $location        = get_post_meta($get_id, 'location', true);
             $test_mode       = get_post_meta($get_id, 'test_mode', true);

             // set $global_loading as boolean
             $global_loading = $global_loading === 'disabled' ? false : true;

            if (isset($location)) {

                // default popup place
                $popup_place     = ' place-center-centered';

                $elm_popup_place = $location ===  'left-topped'     ? ' place-left-topped'     : $popup_place;
                $elm_popup_place = $location ===  'left-centered'   ? ' place-left-centered'   : $elm_popup_place;
                $elm_popup_place = $location ===  'left-bottomed'   ? ' place-left-bottomed'   : $elm_popup_place;
                $elm_popup_place = $location ===  'center-topped'   ? ' place-center-topped'   : $elm_popup_place;
                $elm_popup_place = $location ===  'center'          ? ' place-center-centered' : $elm_popup_place;
                $elm_popup_place = $location ===  'center-bottomed' ? ' place-center-bottomed' : $elm_popup_place;
                $elm_popup_place = $location ===  'right-topped'    ? ' place-right-topped'    : $elm_popup_place;
                $elm_popup_place = $location ===  'right-centered'  ? ' place-right-centered'  : $elm_popup_place;
                $elm_popup_place = $location ===  'right-bottomed'  ? ' place-right-bottomed'  : $elm_popup_place;

                $popup_place = $elm_popup_place;

                $inject_place = $location === 'top'    ? ' place-top'    : 'head';
                $inject_place = $location === 'bottom' ? ' place-bottom' : $inject_place;

                // location - InjectAny or FloatAny
                $place = get_post_type($get_id) === 'float_any' ? $popup_place : $inject_place;

                $args = array(
                    'global'         => $global_loading,
                    'location'       => $place,
                    'test_mode'      => $test_mode,
                );

            }

            return $args;

        }


        /**
         * Basics options.
         * 
         * @param int $get_id Receive the id of the panel.
         * 
         * @return array.
         */
        public static function basics( $get_id )
        {

            $asign_metabox = get_post_type($get_id) === 'float_any'  ? '_mb_floatany'  : false;
            $asign_metabox = get_post_type($get_id) === 'inject_any' ? '_mb_injectany' : $asign_metabox;
            $asign_metabox = get_post_type($get_id) === 'wp_block'
                          && class_exists('Max_Boxy_Reusable_Blocks')
                          && Max_Boxy_Reusable_Blocks::enabled() === true
                          ? '_mb_injectany' : $asign_metabox;

            if ($asign_metabox === false) {
                return;
            }

            $settings   =   get_post_meta($get_id, $asign_metabox, true);
            $basics     =   isset($settings[ 'box_options' ]) ?  $settings[ 'box_options' ] : '';


            // Popup style. Default -> "bumpin" for FloatAny and onload" for InjectAny
            $showing_style =   get_post_type($get_id) === 'float_any' ? ' style-bumpin' : ' style-onload';

                // bypass any potential notices & warnings
            if (isset($basics[ 'panel_popup_style' ])) {

                $elm_showing_style = $basics[ 'panel_popup_style' ] === 'onpageload'       ? ' style-onload'           : $showing_style;
                $elm_showing_style = $basics[ 'panel_popup_style' ] === 'bump'             ? ' style-bumpin'           : $elm_showing_style;
                $elm_showing_style = $basics[ 'panel_popup_style' ] === 'fade'             ? ' style-fadein'           : $elm_showing_style;
                $elm_showing_style = $basics[ 'panel_popup_style' ] === 'slide-horizontal' ? ' style-slide-horizontal' : $elm_showing_style;
                $elm_showing_style = $basics[ 'panel_popup_style' ] === 'slide-vertical'   ? ' style-slide-vertical'   : $elm_showing_style;
                $elm_showing_style = $basics[ 'panel_popup_style' ] === 'push-up'          ? ' style-push-up'          : $elm_showing_style;
                $elm_showing_style = $basics[ 'panel_popup_style' ] === 'push-left'        ? ' style-push-left'        : $elm_showing_style;
                $elm_showing_style = $basics[ 'panel_popup_style' ] === 'push-right'       ? ' style-push-right'       : $elm_showing_style;
                $elm_showing_style = $basics[ 'panel_popup_style' ] === 'push-down'        ? ' style-push-down'        : $elm_showing_style;
                $elm_showing_style = $basics[ 'panel_popup_style' ] === 'alignwide'        ? ' style-alignwide'        : $elm_showing_style;
                $elm_showing_style = $basics[ 'panel_popup_style' ] === 'alignfull'        ? ' style-alignfull'        : $elm_showing_style;

                $showing_style     = ! empty($basics[ 'panel_popup_style' ]) ? $elm_showing_style : $showing_style;

            }

            /*
             * Colors
             */

            // panel background
            $panel_bg       = isset($basics[ 'panel_popup_bg' ])                ? $basics[ 'panel_popup_bg' ] : '';

            $set_panel_bg   = ! empty($panel_bg[ 'background-image' ][ 'url' ]) ? 'background-image:url('  .$panel_bg[ 'background-image' ][ 'url' ] .');' :'';
            $set_panel_bg  .= ! empty($panel_bg[ 'background-repeat' ])         ? 'background-repeat:'     .$panel_bg[ 'background-repeat' ]         .';'  :'';
            $set_panel_bg  .= ! empty($panel_bg[ 'background-position' ])       ? 'background-position:'   .$panel_bg[ 'background-position' ]       .';'  :'';
            $set_panel_bg  .= ! empty($panel_bg[ 'background-attachment' ])     ? 'background-attachment:' .$panel_bg[ 'background-attachment' ]     .';'  :'';
            $set_panel_bg  .= ! empty($panel_bg[ 'background-size' ])           ? 'background-size:'       .$panel_bg[ 'background-size' ]           .';'  :'';
            $set_panel_bg  .= ! empty($panel_bg[ 'background-color' ])          ? 'background-color:'      .$panel_bg[ 'background-color' ]          .';'  :'';

            $panel_color                    =   !empty($basics['panel_popup_color']) ? 'color:' .$basics['panel_popup_color'] .';' : '';

            $trig_bg                        = !empty($basics['panel_shut_bg']) && $basics['panel_shut_bg'] !== '#333333' ? 'background:' .$basics['panel_shut_bg'] .';' : '';

            $trig_color                     = !empty($basics['panel_shut_color']) && $basics['panel_shut_color'] !== '#ffffff' ? 'color:' .$basics['panel_shut_color'] .';' : '';

            // z-index
            $zindex                    = isset($basics[ 'zindex' ]) && is_numeric($basics[ 'zindex' ]) ? 'z-index:' .intval($basics[ 'zindex' ]) .';' : '';
            $_escaped_panel_wrap_style = ! empty($zindex) ? ' style="' .esc_attr($zindex) . '"' : '';

            // overlay
            $use_overlay               = ! empty($basics[ 'use_overlay' ]) ? true : false;

            // sticky
            $sticky                    = ! empty($basics[ 'set_sticky' ])  ? ' is-sticky' : '';

            // panel trig
            $panel_type                = isset($basics[ 'panel_type' ]) ? $basics[ 'panel_type' ]   : 'closer';
            $trig_class                = isset($basics[ 'panel_type' ]) ? ' type-' .$basics[ 'panel_type' ]  : ' type-toggler';

            // panel roles
            $get_roles                 = ! empty($basics[ 'panel_roles' ]) ? $basics[ 'panel_roles' ] : '';

            /*
             * If the type is 'closer' but 'role-igniter' is leftover from the
             * previos toggler type selection, remove 'role-igniter'
             */
            if ($panel_type === 'closer' && is_array($get_roles) && in_array('role-igniter', $get_roles)) {
                array_pop($get_roles);
            }

            /*
             * If the Conversion tracking isn't enabled, prevent output of the
             * 'role-banish' coz in JS localStorage is used to handle banished panels
             */
            if (Max_Boxy_Track::enabled() !== true && $panel_type === 'closer' && is_array($get_roles) && ($key = array_search('role-banish', $get_roles)) !== false) {
                unset($get_roles[$key]);
            }

            // Convert array to a string
            $roles       = is_array($get_roles) ? implode(' ', $get_roles) : '';
            /*
             * If the 'closer' is selected, prepend a space before
             * the output, so it adds correctly to the existing classes
             */
            $panel_roles = $panel_type === 'closer' && ! empty($roles)  ? ' ' .$roles : '';


            /*
             * Rotator and igniter are checked multiple times below,
             * since make the condtion check here.
             */
            $rotator     = is_array($get_roles) && in_array('role-rotator', $get_roles)    ?   true :   false;
            $igniter     = $panel_type === 'toggler' && is_array($get_roles) && in_array('role-igniter', $get_roles) ? true : false;

            $hidden      = $panel_type === 'closer' && is_array($get_roles) && in_array('role-hidden', $get_roles)   ? true : false;

            /*
             * With toggler - role-rotator and role-igniter are the only
             * options in UI, other options are hidden. So only check for them.
             */
            $panel_roles                   .= $panel_type === 'toggler' && $rotator === true ? ' role-rotator' : '';
            $panel_roles                   .= $igniter === true ? ' role-igniter' : '';

            $injectany_preload              = $showing_style === ' style-onload' && $igniter === false && $hidden === false ? ' on' : ''; // reveal on page load, i.e. no waiting to add 'on'
            $panel_strain                   = get_post_type($get_id) === 'float_any' ? ' floatany' : '';
            $panel_strain                   = get_post_type($get_id) === 'wp_block' && class_exists('Max_Boxy_Reusable_Blocks') && Max_Boxy_Reusable_Blocks::enabled() === true
                                            ? ' is-reusable-block injectany' .$injectany_preload : $panel_strain;
            $panel_strain                   = get_post_type($get_id) === 'inject_any' ? ' injectany' .$injectany_preload : $panel_strain;

            /*
             * Toggler
             */
            $unset_toggler                  = ! empty($basics[ 'unset_toggler' ]) ? $basics[ 'unset_toggler' ] : 'no';

            // Sets wheather to fully or partially unset the toggler/closer button.
            $unset_toggler_class            = $unset_toggler === 'all'    ?   ' hide-default-toggler-closer' : '';
            $unset_toggler_class            = $unset_toggler === 'closer' ?   ' hide-default-closer' : $unset_toggler_class;

            // toggler data
            $basics[ 'button_open_svg' ]    = isset($basics[ 'button_open_svg' ])  ? $basics[ 'button_open_svg' ] : '';
            $basics[ 'button_close_svg' ]   = isset($basics[ 'button_close_svg' ]) ? $basics[ 'button_close_svg' ] : '';
            $open_button_data               = empty($basics[ 'button_open_img' ]['url'])  && $basics[ 'button_open_svg' ]  === 'no' && $panel_type === 'toggler' && ! empty($basics[ 'button_open_icon' ]) ? ' data-button-open="' .esc_attr($basics[ 'button_open_icon' ]) .'"' : ''; // ' data-button-open="iks-plus"';
            $close_button_data              = empty($basics[ 'button_close_img' ]['url']) && $basics[ 'button_close_svg' ] === 'no' && ! empty($basics[ 'button_close_icon' ]) ? ' data-button-close="' .esc_attr($basics[ 'button_close_icon' ]) .'"' : ''; // ' data-button-close="iks"';
            $_escaped_toggler_data          = $open_button_data .$close_button_data;
            
            $trigger_icon_classes           = ! empty($open_button_data) ? ' has-icon-open' : '';
            $trigger_icon_classes          .= $unset_toggler === 'no' && ! empty($close_button_data) ? ' has-icon-close' : '';

            $icon_open_class                = empty($basics[ 'button_open_img' ]['url'])  && $basics[ 'button_open_svg' ]  === 'no' && $panel_type === 'toggler' && ! empty($basics[ 'button_open_icon' ]) ? ' ' .$basics[ 'button_open_icon' ] : '';
            $icon_close_class               = empty($basics[ 'button_close_img' ]['url']) && $basics[ 'button_close_svg' ] === 'no' && ! empty($basics[ 'button_close_icon' ]) ? ' ' .$basics[ 'button_close_icon' ] : '';

            $toggler_start_title            = $igniter === true ? esc_html__('Open', 'maxboxy') : esc_html__('Close', 'maxboxy');
            $toggler_start_class            = $igniter === true ? $icon_open_class : $icon_close_class;

            // svg
            // compare two svg (if returns 0, the strings are the same)
            $open_close_svg_the_same        = $panel_type === 'toggler' && $basics[ 'button_open_svg' ] !== 'no' && $basics[ 'button_close_svg' ] !== 'no' ? strcmp($basics[ 'button_open_svg' ], $basics[ 'button_close_svg' ]) : 1;
            $open_svg_class                 = empty($basics[ 'button_open_img' ]['url']) && $basics[ 'button_open_svg' ] !== 'no' && $panel_type === 'toggler' ? ' has-svg-open' : '';
            $the_same_svg                   = $open_close_svg_the_same === 0 ? ' close-svg-thesame' : '';
            $close_svg_class                = empty($basics[ 'button_close_img' ]['url']) && $basics[ 'button_close_svg' ] !== 'no' && $open_close_svg_the_same !== 0 ? ' has-svg-close' : $the_same_svg;
            $toggler_svg_classes            = $open_svg_class .$close_svg_class;


            /**
             * Svg icons source
             *
             * Svg icons used from https://www.svgrepo.com/
             *
             * @license MIT
             *
             * @link https://www.svgrepo.com/page/licensing/
             */
            $svg_bg    = !empty($basics['panel_shut_bg'])    && $basics['panel_shut_bg']    !== '#333333' ? $basics['panel_shut_bg']    : '#333333';
            $svg_color = !empty($basics['panel_shut_color']) && $basics['panel_shut_color'] !== '#ffffff' ? $basics['panel_shut_color'] : '#ffffff';

            $svg_open = '';
            if (! empty($basics[ 'button_open_svg' ]) ) {
                switch ( $basics[ 'button_open_svg' ] ) {
                case $basics[ 'button_open_svg' ] === 'svg-app':
                    $svg_open = '<svg class="trig-svg-open" fill="' .esc_attr($svg_color) .'" height="200px" width="200px" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="-2.4 -2.4 28.80 28.80" enable-background="new 0 0 24 24" xml:space="preserve" stroke="' .esc_attr($svg_color) .'"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-2.4" y="-2.4" width="28.80" height="28.80" rx="0" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <g> <path d="M6,6H2V2h4V6z M14,2h-4v4h4V2z M22,2h-4v4h4V2z M6,10H2v4h4V10z M14,10h-4v4h4V10z M22,10h-4v4h4V10z M6,18H2v4h4V18z M14,18h-4v4h4V18z M22,18h-4v4h4V18z"></path> </g> </g></svg>';
                    break;
                case $basics[ 'button_open_svg' ] === 'svg-app-2':
                    $svg_open = '<svg class="trig-svg-open" fill="' .esc_attr($svg_color) .'" viewBox="-2.4 -2.4 28.80 28.80" xmlns="http://www.w3.org/2000/svg" stroke="' .esc_attr($svg_color) .'" stroke-width="0.00024000000000000003"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-2.4" y="-2.4" width="28.80" height="28.80" rx="0" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <path fill-rule="evenodd" d="M20,22 C18.8954305,22 18,21.1045695 18,20 C18,18.8954305 18.8954305,18 20,18 C21.1045695,18 22,18.8954305 22,20 C22,21.1045695 21.1045695,22 20,22 Z M20,14 C18.8954305,14 18,13.1045695 18,12 C18,10.8954305 18.8954305,10 20,10 C21.1045695,10 22,10.8954305 22,12 C22,13.1045695 21.1045695,14 20,14 Z M20,6 C18.8954305,6 18,5.1045695 18,4 C18,2.8954305 18.8954305,2 20,2 C21.1045695,2 22,2.8954305 22,4 C22,5.1045695 21.1045695,6 20,6 Z M12,22 C10.8954305,22 10,21.1045695 10,20 C10,18.8954305 10.8954305,18 12,18 C13.1045695,18 14,18.8954305 14,20 C14,21.1045695 13.1045695,22 12,22 Z M12,14 C10.8954305,14 10,13.1045695 10,12 C10,10.8954305 10.8954305,10 12,10 C13.1045695,10 14,10.8954305 14,12 C14,13.1045695 13.1045695,14 12,14 Z M12,6 C10.8954305,6 10,5.1045695 10,4 C10,2.8954305 10.8954305,2 12,2 C13.1045695,2 14,2.8954305 14,4 C14,5.1045695 13.1045695,6 12,6 Z M4,22 C2.8954305,22 2,21.1045695 2,20 C2,18.8954305 2.8954305,18 4,18 C5.1045695,18 6,18.8954305 6,20 C6,21.1045695 5.1045695,22 4,22 Z M4,14 C2.8954305,14 2,13.1045695 2,12 C2,10.8954305 2.8954305,10 4,10 C5.1045695,10 6,10.8954305 6,12 C6,13.1045695 5.1045695,14 4,14 Z M4,6 C2.8954305,6 2,5.1045695 2,4 C2,2.8954305 2.8954305,2 4,2 C5.1045695,2 6,2.8954305 6,4 C6,5.1045695 5.1045695,6 4,6 Z"></path> </g></svg>';
                    break;
                case $basics[ 'button_open_svg' ] === 'svg-app-3':
                    $svg_open = '<svg class="trig-svg-open" viewBox="-7.2 -7.2 38.40 38.40" xmlns="http://www.w3.org/2000/svg" fill="' .esc_attr($svg_color) .'"><g id="SVGRepo_bgCarrier" stroke-width="0"><rect x="-7.2" y="-7.2" width="38.40" height="38.40" rx="19.2" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g id="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g id="SVGRepo_iconCarrier"><path d="M5.5 4A1.5 1.5 0 1 1 4 2.5 1.5 1.5 0 0 1 5.5 4zM12 2.5A1.5 1.5 0 1 0 13.5 4 1.5 1.5 0 0 0 12 2.5zm8 0A1.5 1.5 0 1 0 21.5 4 1.5 1.5 0 0 0 20 2.5zm-16 8A1.5 1.5 0 1 0 5.5 12 1.5 1.5 0 0 0 4 10.5zm8 0a1.5 1.5 0 1 0 1.5 1.5 1.5 1.5 0 0 0-1.5-1.5zm8 0a1.5 1.5 0 1 0 1.5 1.5 1.5 1.5 0 0 0-1.5-1.5zm-16 8A1.5 1.5 0 1 0 5.5 20 1.5 1.5 0 0 0 4 18.5zm8 0a1.5 1.5 0 1 0 1.5 1.5 1.5 1.5 0 0 0-1.5-1.5zm8 0a1.5 1.5 0 1 0 1.5 1.5 1.5 1.5 0 0 0-1.5-1.5z"></path><path fill="none" d="M0 0h24v24H0z"></path></g></svg>';
                    break;
                case $basics[ 'button_open_svg' ] === 'svg-basket':
                    $svg_open = '<svg class="trig-svg-open" fill="' .esc_attr($svg_color) .'" viewBox="-172.8 -172.8 921.60 921.60" xmlns="http://www.w3.org/2000/svg" stroke="' .esc_attr($svg_color) .'"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-172.8" y="-172.8" width="921.60" height="921.60" rx="460.8" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"><path d="M576 216v16c0 13.255-10.745 24-24 24h-8l-26.113 182.788C514.509 462.435 494.257 480 470.37 480H105.63c-23.887 0-44.139-17.565-47.518-41.212L32 256h-8c-13.255 0-24-10.745-24-24v-16c0-13.255 10.745-24 24-24h67.341l106.78-146.821c10.395-14.292 30.407-17.453 44.701-7.058 14.293 10.395 17.453 30.408 7.058 44.701L170.477 192h235.046L326.12 82.821c-10.395-14.292-7.234-34.306 7.059-44.701 14.291-10.395 34.306-7.235 44.701 7.058L484.659 192H552c13.255 0 24 10.745 24 24zM312 392V280c0-13.255-10.745-24-24-24s-24 10.745-24 24v112c0 13.255 10.745 24 24 24s24-10.745 24-24zm112 0V280c0-13.255-10.745-24-24-24s-24 10.745-24 24v112c0 13.255 10.745 24 24 24s24-10.745 24-24zm-224 0V280c0-13.255-10.745-24-24-24s-24 10.745-24 24v112c0 13.255 10.745 24 24 24s24-10.745 24-24z"></path></g></svg>';
                    break;
                case $basics[ 'button_open_svg' ] === 'svg-basket-+':
                    $svg_open = '<svg class="trig-svg-open" fill="' .esc_attr($svg_color) .'" height="200px" width="200px" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="-9.6 -9.6 51.20 51.20" xml:space="preserve" stroke="' .esc_attr($svg_color) .'"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-9.6" y="-9.6" width="51.20" height="51.20" rx="25.6" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <path d="M29,13h-2h-4.5l2.6-6.1c0.3-0.6,0.3-1.4-0.1-1.9c-0.4-0.6-1-0.9-1.7-0.9h-7.1c-1.1,0-2.2,0.6-2.7,1.7L10.3,13H5H3 c-0.6,0-1,0.4-1,1s0.4,1,1,1h1.1l1.5,9.6c0.3,2,2,3.4,4,3.4h12.9c2,0,3.7-1.4,4-3.4l1.5-9.6H29c0.6,0,1-0.4,1-1S29.6,13,29,13z M19,21h-2v2c0,0.6-0.4,1-1,1s-1-0.4-1-1v-2h-2c-0.6,0-1-0.4-1-1s0.4-1,1-1h2v-2c0-0.6,0.4-1,1-1s1,0.4,1,1v2h2c0.6,0,1,0.4,1,1 S19.6,21,19,21z M20.3,13h-7.8l2.8-6.4C15.5,6.2,15.9,6,16.2,6l7.1,0L20.3,13z"></path> </g></svg>';
                    break;
                case $basics[ 'button_open_svg' ] === 'svg-basket-+2':
                    $svg_open = '<svg class="trig-svg-open" fill="' .esc_attr($svg_color) .'" viewBox="-9.3 -9.3 49.60 49.60" xmlns="http://www.w3.org/2000/svg" stroke="' .esc_attr($svg_color) .'"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-9.3" y="-9.3" width="49.60" height="49.60" rx="24.8" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"><path d="m19.478 22.099q0-.046 0-.091h-5.728q0 .045 0 .091c0 .013.001.029.001.045 0 1.05-.851 1.901-1.901 1.901s-1.901-.851-1.901-1.901c0-.016 0-.031.001-.047v.002q0-.046 0-.091h-.653c-.584 0-1.073-.411-1.192-.96l-.001-.008-3.817-18.073-3.261-.543c-.56-.119-.974-.609-.974-1.196 0-.674.547-1.221 1.221-1.221.053 0 .105.003.157.01l-.006-.001 4.081.68c.497.085.887.461.991.943l.001.008.692 3.264 11.905.992c-.069.356-.11.766-.112 1.186v.001.003c0 .402.035.796.103 1.179l-.006-.04c-.571.183-.977.709-.977 1.33 0 .093.009.183.026.271l-.001-.009.719 5.19c.044.333.196.625.418.845.202.201.479.327.786.33h.001c.068 0 .135-.007.199-.019l-.007.001c.601-.16 1.038-.699 1.038-1.341 0-.09-.009-.179-.025-.264l.001.009-.392-2.822c1.216 1.261 2.92 2.044 4.808 2.044.043 0 .086 0 .128-.006l.093-.005-.669 3.902c-.033.193-.2.339-.4.339h-.001-14.864l.327 1.547h14.157c.659.02 1.185.559 1.185 1.22s-.526 1.2-1.183 1.22h-.002-1.164q0 .045 0 .091c0 1.05-.851 1.901-1.901 1.901s-1.901-.851-1.901-1.901zm1.358 0c.001.297.242.537.539.537s.539-.241.539-.539c0-.031-.003-.062-.008-.092v.003h-1.06c-.005.027-.008.059-.008.091zm-9.528 0c.001.297.242.537.539.537s.539-.241.539-.539c0-.031-.003-.062-.008-.092v.003h-1.061c-.005.027-.007.057-.007.089v.002zm3.867-13.875c-.601.159-1.038.699-1.038 1.34 0 .091.009.179.025.265l-.001-.009.719 5.19c.044.333.196.625.418.845.202.201.479.327.786.33h.001c.068 0 .135-.007.199-.019l-.007.001c.601-.16 1.038-.699 1.038-1.341 0-.09-.009-.179-.025-.264l.001.009-.719-5.19c-.044-.333-.196-.625-.418-.845-.202-.201-.479-.327-.786-.331h-.001c-.069 0-.136.007-.201.02l.007-.001zm-3.966 0c-.603.159-1.04.699-1.04 1.341 0 .092.009.181.026.268l-.001-.009.719 5.19c.044.333.196.625.418.845.202.201.479.327.786.33h.001c.068 0 .135-.007.199-.019l-.007.001c.602-.159 1.039-.699 1.039-1.341 0-.09-.009-.178-.025-.264l.001.009-.72-5.193c-.044-.333-.196-.625-.418-.845-.202-.202-.479-.327-.786-.331h-.001c-.068 0-.134.007-.198.019zm8.789-1.128c0-3.136 2.542-5.678 5.678-5.678s5.678 2.542 5.678 5.678-2.542 5.678-5.678 5.678c-3.136-.002-5.677-2.543-5.68-5.679zm1.627 0c.001 2.237 1.814 4.05 4.051 4.05s4.051-1.814 4.051-4.051-1.814-4.051-4.051-4.051c-2.237.002-4.05 1.814-4.053 4.051zm3.24 1.621v-.808h-.808c-.449 0-.814-.364-.814-.814s.364-.814.814-.814h.808v-.808c0-.449.364-.814.814-.814s.814.364.814.814v.808h.808c.449 0 .814.364.814.814s-.364.814-.814.814h-.808v.807c0 .449-.364.814-.814.814s-.814-.364-.814-.814z"></path></g></svg>';
                    break;
                case $basics[ 'button_open_svg' ] === 'svg-book':
                    $svg_open = '<svg class="trig-svg-open" version="1.0" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="-32 -32 128.00 128.00" enable-background="new 0 0 64 64" xml:space="preserve" fill="' .esc_attr($svg_bg) .'"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-32" y="-32" width="128.00" height="128.00" rx="64" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <path fill="' .esc_attr($svg_color) .'" d="M60,52V4c0-2.211-1.789-4-4-4H14v51v3h42v8H10c-2.209,0-4-1.791-4-4s1.791-4,4-4h2v-3V0H8 C5.789,0,4,1.789,4,4v54c0,3.313,2.687,6,6,6h49c0.553,0,1-0.447,1-1s-0.447-1-1-1h-1v-8C59.104,54,60,53.104,60,52z M23,14h12 c0.553,0,1,0.447,1,1s-0.447,1-1,1H23c-0.553,0-1-0.447-1-1S22.447,14,23,14z M42,28H23c-0.553,0-1-0.447-1-1s0.447-1,1-1h19 c0.553,0,1,0.447,1,1S42.553,28,42,28z M49,22H23c-0.553,0-1-0.447-1-1s0.447-1,1-1h26c0.553,0,1,0.447,1,1S49.553,22,49,22z"></path> </g></svg>';
                    break;
                case $basics[ 'button_open_svg' ] === 'svg-cookie':
                    $svg_open = '<svg class="trig-svg-open" viewBox="-4.35 -4.35 23.70 23.70" fill="none" xmlns="http://www.w3.org/2000/svg"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-4.35" y="-4.35" width="23.70" height="23.70" rx="11.85" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <path fill-rule="evenodd" clip-rule="evenodd" d="M12.0697 1.76746C12.4807 1.21947 11.4605 0.454311 11.0495 1.0023C10.6385 1.55028 11.6588 2.31544 12.0697 1.76746ZM8.39263 1.07811C7.15585 0.950602 5.7823 1.16348 4.58433 1.70937C3.38552 2.25563 2.32735 3.15309 1.78844 4.41832C1.37574 5.38724 1.01715 6.28113 1.00088 7.44354C0.984724 8.59844 1.30522 9.96898 2.13174 11.928C2.61142 13.0649 4.03963 13.5446 5.13895 13.8079C6.40836 14.1119 7.80857 14.1914 8.6644 14.0742C9.36515 13.9782 10.1448 13.8284 10.7987 13.297C11.8977 12.4039 12.9009 11.3955 13.4994 10.3393C14.104 9.27221 14.3256 8.09207 13.7216 6.95324C13.5628 6.65373 13.316 6.57734 13.0412 6.4923C12.9374 6.46016 12.8295 6.42678 12.7209 6.37966C11.6211 5.90234 10.9646 5.34963 10.9135 5.02876C10.8656 4.72808 10.9221 4.51463 10.9811 4.29181C11.0129 4.17199 11.0453 4.04947 11.0626 3.90922C11.0838 3.73737 11.0814 3.33319 10.6996 3.12761C10.4048 2.96888 10.2164 2.65843 10.0407 2.36904C9.99742 2.29775 9.95492 2.22773 9.9118 2.16158C9.62634 1.72367 9.20769 1.16213 8.39263 1.07811ZM4.99899 2.61935C3.96483 3.09058 3.12554 3.83097 2.70846 4.81018C2.29808 5.77368 2.01406 6.50873 2.00079 7.45753C1.98741 8.41385 2.25043 9.6368 3.0531 11.5393C3.39181 12.3421 4.62167 12.6557 5.37186 12.8354C6.5493 13.1174 7.822 13.1802 8.52868 13.0834C9.21271 12.9897 9.74568 12.8642 10.1681 12.5209C11.229 11.6587 12.121 10.7435 12.6293 9.84635C12.9349 9.30709 13.5141 7.7028 12.6292 7.3873C10.7539 6.71875 10.262 6.06669 9.99011 5.41268C9.80915 4.97744 9.82868 4.52282 9.95741 4.07885L9.95741 4.07884C9.97662 4.0126 9.99538 3.94791 10.0334 3.88882C9.81857 3.73676 9.6515 3.55195 9.51464 3.3715C9.42876 3.25828 9.3469 3.12099 9.26197 2.97856C9.01866 2.57052 8.75018 2.12027 8.29008 2.07283C7.22889 1.96343 6.03398 2.14772 4.99899 2.61935ZM13.2081 3.77471C13.441 3.22671 12.4547 2.63606 12.0822 3.10163C11.5817 3.72732 12.9029 4.49281 13.2081 3.77471ZM14.3672 2.26031C14.9668 2.27493 15.1551 1.11603 14.5718 0.949371C13.8076 0.731026 13.5918 2.24139 14.3672 2.26031ZM14.2857 5.09098C14.8644 5.10004 15.0462 4.38222 14.4832 4.27899C13.7455 4.14375 13.5373 5.07927 14.2857 5.09098ZM6.9075 4.28672C6.46898 4.66754 6.0522 4.15185 5.97983 3.7365C5.86848 3.09744 6.33696 2.56856 6.94823 2.91156C7.43344 3.18382 7.26678 3.97471 6.9075 4.28672ZM4.94455 5.88184C5.40885 5.41754 4.59567 4.57013 4.11425 5.05154C3.83338 5.33242 4.00936 5.65376 4.23744 5.88184C4.43271 6.0771 4.74929 6.0771 4.94455 5.88184ZM6.97716 6.71984C7.31181 7.38914 8.48804 6.79159 7.99413 6.14788C7.86519 5.97983 7.68657 5.9494 7.62145 5.94207C7.21217 5.89601 6.76349 6.2925 6.97716 6.71984ZM6.98798 8.72461C7.14066 9.1188 7.51122 9.3187 7.91915 9.1633C8.27434 9.02799 8.33186 8.39689 8.17175 8.07427C8.02331 7.77514 7.63956 7.67793 7.33747 7.79417C6.98512 7.92976 6.85672 8.38708 6.98576 8.71889L6.98798 8.72461ZM10.3885 8.84081C10.7575 8.6566 11.4617 8.82771 11.4617 9.31199C11.4617 9.71286 10.9587 10.2165 10.5634 10.2826C10.1813 10.3465 9.70515 9.97581 9.76648 9.57718C9.81445 9.26539 10.1217 8.97401 10.3885 8.84081ZM7.56704 10.8432C7.33461 10.7502 7.14353 10.8601 7.11437 10.8769L7.11279 10.8778C6.90782 10.9949 6.71383 11.2439 6.6747 11.4842C6.59018 12.0034 7.13199 12.1239 7.52661 12.0987C8.2074 12.0553 8.06547 11.0426 7.56704 10.8432ZM4.8805 10.8932C5.0674 10.7723 5.15658 10.5363 5.08293 10.3153C4.93046 9.79687 4.3246 9.71252 3.96561 10.1297C3.79336 10.3299 3.80749 10.6274 3.99214 10.8105L3.99495 10.814L3.9979 10.8176C4.22025 11.0942 4.63624 11.1857 4.8805 10.8932ZM3.04695 7.81318C3.33147 8.0977 3.60077 8.15067 3.98443 8.05859C4.60826 7.90887 4.13814 6.24299 3.047 6.87296C2.70939 7.06788 2.86716 7.63339 3.04695 7.81318Z" fill="' .esc_attr($svg_color) .'"></path> </g></svg>';
                    break;
                case $basics[ 'button_open_svg' ] === 'svg-cookie-2':
                    $svg_open = '<svg class="trig-svg-open" fill="' .esc_attr($svg_color) .'" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="-270.06 -270.06 1440.32 1440.32" xml:space="preserve" stroke="' .esc_attr($svg_color) .'"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-270.06" y="-270.06" width="1440.32" height="1440.32" rx="720.16" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <g> <g> <path d="M219.1,515.652c0-6.7,0.4-13.3,1-19.8c-93-27.101-161.8-88.4-161.8-159.7c0-13.8,0.4-37.7,1.1-39.9 c21.2,52.5,100.6,94.3,193.3,109.2l46.7-74.6c10.101-16.1,22.601-30.5,37.3-42.9c14.101-11.9,30.2-22.1,48-30.2 c21.301-9.7,44.5-16.4,69.5-20.1c-2.599-3.6-4.199-8-4.199-12.8c0-12,10-22,22-22s22,10,22,22c0,3.4-0.801,6.7-2.199,9.6 c3.1-0.1,6.1-0.1,9.199-0.1c48.801,0,100,10.3,149.9,29.8c-0.701-121.9-146.201-221-325.4-221c-179.601,0-325.4,99.8-325.4,222.1 l-0.1,97.3c0,98.6,94.9,182,225.8,210.6C221.3,553.652,219,534.452,219.1,515.652z M432.5,107.952c12,0,22,10,22,22s-10,22-22,22 s-22-10-22-22S420.4,107.952,432.5,107.952z M346.5,182.952c12,0,22,10,22,22s-10,22-22,22s-22-10-22-22 S334.5,182.952,346.5,182.952z M264.9,132.252c12,0,22,10,22,22s-10,22-22,22s-22-10-22-22S252.9,132.252,264.9,132.252z M214.2,233.652c12,0,22,10,22,22s-10,22-22,22s-22-10-22-22S202.2,233.652,214.2,233.652z M152.5,174.052c12,0,22,10,22,22 s-10,22-22,22s-22-10-22-22C130.5,184.152,140.5,174.052,152.5,174.052z"></path> <path d="M718.5,331.452c-22.1-13.9-44.699-25.5-67.4-35.1c-51.1-21.5-102.6-32.1-149.9-32.1c-76.5,0-141.899,27.8-176.299,82.5 l-39.3,62.7l-12.4,19.8c-14,22.4-21.7,47.4-23.6,73.9c-1.8,24.4,1.4,50,9,75.8c22.4,76.2,83.6,154.601,172.6,210.5 c72.101,45.2,149.5,67.601,217.9,67.601c76,0,140.801-27.601,175-82.101c0.5-0.8,50.1-79.899,51.9-82.7 C941,588.552,870.6,426.852,718.5,331.452z M716.801,566.452c0,12-10,22-22,22s-22-10-22-22s10-22,22-22 S716.801,554.452,716.801,566.452z M688.1,405.552c12,0,22,10,22,22s-10,22-22,22s-22-10-22-22S676.1,405.552,688.1,405.552z M593.4,511.352c0,12-10,22-22,22c-8.301,0-15.701-4.8-19.5-11.8c-1.6-3.101-2.6-6.601-2.6-10.2c0-12,10-22,22-22 c5.699,0,10.898,2.2,14.799,5.899C590.6,499.251,593.4,504.952,593.4,511.352z M624.199,420.952c0,12-10,22-22,22s-22-10-22-22 s10-22,22-22S624.199,408.952,624.199,420.952z M518.4,341.652c9.1,0,17.1,5.8,20.4,13.8c1.1,2.601,1.699,5.3,1.699,8.3 c0,12-10,22-22,22c-7.5,0-14.1-3.899-18.1-9.699c-2.5-3.5-3.9-7.801-3.9-12.4C496.4,351.652,506.4,341.652,518.4,341.652z M789.1,721.751c-51.199,81.7-199.299,81.101-319.1,5.9c-60.5-38-107.1-90.7-131.7-144.1c-11.3-24.601-18-49.301-19.3-72.9 c-1.4-26.5,4-51.5,17.399-72.9c5.101-8.1,13-20.3,17.9-27.5c2.1-3.1,3.7-5.3,4.3-5.699c-0.3,1.8-0.6,3.6-0.8,5.5 c-3.2,28.399,7,62,27,96c12.8,21.899,29.7,43.899,49.6,65c25.2,26.6,55.401,51.5,88.5,72.3c102.699,64.399,230.5,86.6,288,45 C810.9,688.251,796.5,710.052,789.1,721.751z M807.199,528.952c0,12-10,22-22,22s-22-10-22-22s10-22,22-22 S807.199,516.952,807.199,528.952z"></path> </g> </g> </g></svg>';
                    break;
                case $basics[ 'button_open_svg' ] === 'svg-chat':
                    $svg_open = '<svg class="trig-svg-open" viewBox="0 0 24.00 24.00" fill="none" xmlns="http://www.w3.org/2000/svg" transform="matrix(1, 0, 0, 1, 0, 0)" stroke="' .esc_attr($svg_color) .'" stroke-width="0.24000000000000005"><g class="SVGRepo_bgCarrier" stroke-width="0" transform="translate(6.6,6.6), scale(0.45)"><rect x="0" y="0" width="24.00" height="24.00" rx="0" fill="' .esc_attr($svg_color) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <path fill-rule="evenodd" clip-rule="evenodd" d="M13.6288 20.4718L13.0867 21.3877C12.6035 22.204 11.3965 22.204 10.9133 21.3877L10.3712 20.4718C9.95073 19.7614 9.74049 19.4063 9.40279 19.2098C9.06509 19.0134 8.63992 19.0061 7.78958 18.9915C6.53422 18.9698 5.74689 18.8929 5.08658 18.6194C3.86144 18.1119 2.88807 17.1386 2.3806 15.9134C2 14.9946 2 13.8297 2 11.5V10.5C2 7.22657 2 5.58985 2.7368 4.38751C3.14908 3.71473 3.71473 3.14908 4.38751 2.7368C5.58985 2 7.22657 2 10.5 2H13.5C16.7734 2 18.4101 2 19.6125 2.7368C20.2853 3.14908 20.8509 3.71473 21.2632 4.38751C22 5.58985 22 7.22657 22 10.5V11.5C22 13.8297 22 14.9946 21.6194 15.9134C21.1119 17.1386 20.1386 18.1119 18.9134 18.6194C18.2531 18.8929 17.4658 18.9698 16.2104 18.9915C15.36 19.0061 14.9349 19.0134 14.5972 19.2098C14.2595 19.4062 14.0492 19.7614 13.6288 20.4718ZM8 11.75C7.58579 11.75 7.25 12.0858 7.25 12.5C7.25 12.9142 7.58579 13.25 8 13.25H13.5C13.9142 13.25 14.25 12.9142 14.25 12.5C14.25 12.0858 13.9142 11.75 13.5 11.75H8ZM7.25 9C7.25 8.58579 7.58579 8.25 8 8.25H16C16.4142 8.25 16.75 8.58579 16.75 9C16.75 9.41421 16.4142 9.75 16 9.75H8C7.58579 9.75 7.25 9.41421 7.25 9Z" fill="' .esc_attr($svg_bg) .'"></path> </g></svg>';
                    break;
                case $basics[ 'button_open_svg' ] === 'svg-chat-2':
                    $svg_open = '<svg class="trig-svg-open" viewBox="-7.2 -7.2 38.40 38.40" fill="' .esc_attr($svg_color) .'" xmlns="http://www.w3.org/2000/svg" transform="matrix(1, 0, 0, 1, 0, 0)"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-7.2" y="-7.2" width="38.40" height="38.40" rx="19.2" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <path d="M12 22C17.5228 22 22 17.5228 22 12C22 6.47715 17.5228 2 12 2C6.47715 2 2 6.47715 2 12C2 13.5997 2.37562 15.1116 3.04346 16.4525C3.22094 16.8088 3.28001 17.2161 3.17712 17.6006L2.58151 19.8267C2.32295 20.793 3.20701 21.677 4.17335 21.4185L6.39939 20.8229C6.78393 20.72 7.19121 20.7791 7.54753 20.9565C8.88837 21.6244 10.4003 22 12 22Z" stroke="' .esc_attr($svg_bg) .'" stroke-width="1.5"></path> <path opacity="0.5" d="M8 12H8.009M11.991 12H12M15.991 12H16" stroke="' .esc_attr($svg_bg) .'" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"></path> </g></svg>';
                    break;
                case $basics[ 'button_open_svg' ] === 'svg-chat-3':
                    $svg_open = '<svg class="trig-svg-open" viewBox="-7.2 -7.2 38.40 38.40" fill="' .esc_attr($svg_color) .'" xmlns="http://www.w3.org/2000/svg" transform="matrix(-1, 0, 0, 1, 0, 0)"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-7.2" y="-7.2" width="38.40" height="38.40" rx="19.2" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <path d="M12 22C17.5228 22 22 17.5228 22 12C22 6.47715 17.5228 2 12 2C6.47715 2 2 6.47715 2 12C2 13.5997 2.37562 15.1116 3.04346 16.4525C3.22094 16.8088 3.28001 17.2161 3.17712 17.6006L2.58151 19.8267C2.32295 20.793 3.20701 21.677 4.17335 21.4185L6.39939 20.8229C6.78393 20.72 7.19121 20.7791 7.54753 20.9565C8.88837 21.6244 10.4003 22 12 22Z" stroke="' .esc_attr($svg_bg) .'" stroke-width="1.5"></path> <path opacity="0.5" d="M8 12H8.009M11.991 12H12M15.991 12H16" stroke="' .esc_attr($svg_bg) .'" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"></path> </g></svg>';
                    break;
                case $basics[ 'button_open_svg' ] === 'svg-chat-4':
                    $svg_open = '<svg class="trig-svg-open" viewBox="0 0 24 24" fill="' .esc_attr($svg_bg) .'" xmlns="http://www.w3.org/2000/svg" transform="matrix(1, 0, 0, 1, 0, 0)"><g class="SVGRepo_bgCarrier" stroke-width="0"></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <path d="M12 22C17.5228 22 22 17.5228 22 12C22 6.47715 17.5228 2 12 2C6.47715 2 2 6.47715 2 12C2 13.5997 2.37562 15.1116 3.04346 16.4525C3.22094 16.8088 3.28001 17.2161 3.17712 17.6006L2.58151 19.8267C2.32295 20.793 3.20701 21.677 4.17335 21.4185L6.39939 20.8229C6.78393 20.72 7.19121 20.7791 7.54753 20.9565C8.88837 21.6244 10.4003 22 12 22Z" stroke="' .esc_attr($svg_color) .'" stroke-width="1.5"></path> <path opacity="0.5" d="M8 10.5H16" stroke="' .esc_attr($svg_color) .'" stroke-width="1.5" stroke-linecap="round"></path> <path opacity="0.5" d="M8 14H13.5" stroke="' .esc_attr($svg_color) .'" stroke-width="1.5" stroke-linecap="round"></path> </g></svg>';
                    break;
                case $basics[ 'button_open_svg' ] === 'svg-chat-5':
                    $svg_open = '<svg class="trig-svg-open" viewBox="0 0 24 24" fill="' .esc_attr($svg_bg) .'" xmlns="http://www.w3.org/2000/svg" transform="matrix(-1, 0, 0, 1, 0, 0)"><g class="SVGRepo_bgCarrier" stroke-width="0"></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <path d="M12 22C17.5228 22 22 17.5228 22 12C22 6.47715 17.5228 2 12 2C6.47715 2 2 6.47715 2 12C2 13.5997 2.37562 15.1116 3.04346 16.4525C3.22094 16.8088 3.28001 17.2161 3.17712 17.6006L2.58151 19.8267C2.32295 20.793 3.20701 21.677 4.17335 21.4185L6.39939 20.8229C6.78393 20.72 7.19121 20.7791 7.54753 20.9565C8.88837 21.6244 10.4003 22 12 22Z" stroke="' .esc_attr($svg_color) .'" stroke-width="1.5"></path> <path opacity="0.5" d="M8 10.5H16" stroke="' .esc_attr($svg_color) .'" stroke-width="1.5" stroke-linecap="round"></path> <path opacity="0.5" d="M8 14H13.5" stroke="' .esc_attr($svg_color) .'" stroke-width="1.5" stroke-linecap="round"></path> </g></svg>';
                    break;
                case $basics[ 'button_open_svg' ] === 'svg-chats':
                    $svg_open = '<svg class="trig-svg-open" viewBox="-8.4 -8.4 40.80 40.80" xmlns="http://www.w3.org/2000/svg" fill="none"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-8.4" y="-8.4" width="40.80" height="40.80" rx="20.4" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <path stroke="' .esc_attr($svg_color) .'" stroke-linejoin="round" stroke-width="2" d="M9.88235 15C13.261 15 16 12.5376 16 9.5C16 6.46243 13.261 4 9.88235 4C6.50367 4 3.76471 6.46243 3.76471 9.5C3.76471 10.3179 3.96327 11.094 4.31942 11.7917L3 15L6.82353 14.2642C7.72335 14.7322 8.76806 15 9.88235 15Z"></path> <path stroke="' .esc_attr($svg_color) .'" stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M10.8042 18.1242C11.759 18.6784 12.8966 19 14.1176 19C15.2319 19 16.2766 18.7322 17.1765 18.2642L21 19L19.6806 15.7917C20.0367 15.094 20.2353 14.3179 20.2353 13.5C20.2353 12.2553 19.7754 11.1071 19 10.1854C18.251 9.29505 17.2076 8.61598 16 8.26526"></path> <circle r="1" fill="' .esc_attr($svg_color) .'" transform="matrix(-1 0 0 1 13 9.5)"></circle> <circle r="1" fill="' .esc_attr($svg_color) .'" transform="matrix(-1 0 0 1 10 9.5)"></circle> <circle r="1" fill="' .esc_attr($svg_color) .'" transform="matrix(-1 0 0 1 7 9.5)"></circle> </g></svg>';
                    break;
                case $basics[ 'button_open_svg' ] === 'svg-chats-2':
                    $svg_open = '<svg class="trig-svg-open" viewBox="-7.2 -7.2 38.40 38.40" xmlns="http://www.w3.org/2000/svg" fill="none"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-7.2" y="-7.2" width="38.40" height="38.40" rx="19.2" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"><path stroke="' .esc_attr($svg_color) .'" stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M8 18.72C6.339 20.134 4.82 21 2 21c1-1 2.27-2.35 2.801-4.447C3.067 15.114 2 13.157 2 11c0-4.418 4.477-8 10-8 5.1 0 9.308 3.054 9.923 7"></path><path fill="' .esc_attr($svg_color) .'" stroke="' .esc_attr($svg_color) .'" stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M16 19.889c-3.314 0-6-1.99-6-4.445C10 12.99 12.686 11 16 11s6 1.99 6 4.444c0 1.199-.64 2.286-1.68 3.085.317 1.165 1.08 1.915 1.68 2.471-1.8 0-2.716-.544-3.792-1.422-.684.2-1.428.31-2.208.31z"></path></g></svg>';
                    break;
                case $basics[ 'button_open_svg' ] === 'svg-chats-3':
                    $svg_open = '<svg class="trig-svg-open" viewBox="-8.4 -8.4 40.80 40.80" xmlns="http://www.w3.org/2000/svg" fill="none"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-8.4" y="-8.4" width="40.80" height="40.80" rx="20.4" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"><path stroke="' .esc_attr($svg_color) .'" stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M13.584 7a5.001 5.001 0 1 0-8.809 4.675L4 14l2.325-.775c.214.136.44.256.675.359"></path><path fill="' .esc_attr($svg_color) .'" stroke="' .esc_attr($svg_color) .'" stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M15 20a5 5 0 1 1 4.225-2.325L20 20l-2.325-.775A4.976 4.976 0 0 1 15 20z"></path></g></svg>';
                    break;
                case $basics[ 'button_open_svg' ] === 'svg-elipsis-h':
                    $svg_open = '<svg class="trig-svg-open" viewBox="-7.2 -7.2 38.40 38.40" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" fill="' .esc_attr($svg_bg) .'" stroke="' .esc_attr($svg_bg) .'"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-7.2" y="-7.2" width="38.40" height="38.40" rx="19.2" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <title>elipsis-h</title> <desc>Created with sketchtool.</desc> <g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"> <g fill="' .esc_attr($svg_color) .'"> <path d="M18,14 C16.8954305,14 16,13.1045695 16,12 C16,10.8954305 16.8954305,10 18,10 C19.1045695,10 20,10.8954305 20,12 C20,13.1045695 19.1045695,14 18,14 Z M6,14 C4.8954305,14 4,13.1045695 4,12 C4,10.8954305 4.8954305,10 6,10 C7.1045695,10 8,10.8954305 8,12 C8,13.1045695 7.1045695,14 6,14 Z M12,14 C10.8954305,14 10,13.1045695 10,12 C10,10.8954305 10.8954305,10 12,10 C13.1045695,10 14,10.8954305 14,12 C14,13.1045695 13.1045695,14 12,14 Z"> </path> </g> </g> </g></svg>';
                    break;
                case $basics[ 'button_open_svg' ] === 'svg-elipsis-v':
                    $svg_open = '<svg class="trig-svg-open" viewBox="-7.2 -7.2 38.40 38.40" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" fill="' .esc_attr($svg_bg) .'"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-7.2" y="-7.2" width="38.40" height="38.40" rx="19.2" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <title>elipsis-h</title> <desc>Created with sketchtool.</desc> <g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"> <g fill="' .esc_attr($svg_color) .'"> <path d="M18,14 C16.8954305,14 16,13.1045695 16,12 C16,10.8954305 16.8954305,10 18,10 C19.1045695,10 20,10.8954305 20,12 C20,13.1045695 19.1045695,14 18,14 Z M6,14 C4.8954305,14 4,13.1045695 4,12 C4,10.8954305 4.8954305,10 6,10 C7.1045695,10 8,10.8954305 8,12 C8,13.1045695 7.1045695,14 6,14 Z M12,14 C10.8954305,14 10,13.1045695 10,12 C10,10.8954305 10.8954305,10 12,10 C13.1045695,10 14,10.8954305 14,12 C14,13.1045695 13.1045695,14 12,14 Z"> </path> </g> </g> </g></svg>';
                    break;
                case $basics[ 'button_open_svg' ] === 'svg-home':
                    $svg_open = '<svg class="trig-svg-open" fill="' .esc_attr($svg_color) .'" viewBox="-9.6 -9.6 43.20 43.20" xmlns="http://www.w3.org/2000/svg" stroke="' .esc_attr($svg_color) .'"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-9.6" y="-9.6" width="43.20" height="43.20" rx="21.6" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"><path d="M3.012,10.981,3,11H5v9a1,1,0,0,0,1,1H18a1,1,0,0,0,1-1V11h2a1,1,0,0,0,.555-1.832l-9-6a1,1,0,0,0-1.11,0l-9,6a1,1,0,0,0-.277,1.387A.98.98,0,0,0,3.012,10.981ZM10,14a1,1,0,0,1,1-1h2a1,1,0,0,1,1,1v5H10Z"></path></g></svg>';
                    break;
                case $basics[ 'button_open_svg' ] === 'svg-home-2':
                    $svg_open = '<svg class="trig-svg-open" fill="' .esc_attr($svg_color) .'" viewBox="-7.2 -7.2 38.40 38.40" xmlns="http://www.w3.org/2000/svg" stroke="' .esc_attr($svg_color) .'"><g id="SVGRepo_bgCarrier" stroke-width="0"><rect x="-7.2" y="-7.2" width="38.40" height="38.40" rx="0" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g id="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g id="SVGRepo_iconCarrier"><path d="M3.012,10.981,3,11H5v9a1,1,0,0,0,1,1H18a1,1,0,0,0,1-1V11h2a1,1,0,0,0,.555-1.832l-9-6a1,1,0,0,0-1.11,0l-9,6a1,1,0,0,0-.277,1.387A.98.98,0,0,0,3.012,10.981ZM10,14a1,1,0,0,1,1-1h2a1,1,0,0,1,1,1v5H10Z"></path></g></svg>';
                    break;
                case $basics[ 'button_open_svg' ] === 'svg-info':
                    $svg_open = '<svg class="trig-svg-open" fill="' .esc_attr($svg_color) .'" viewBox="-9.6 -9.6 51.20 51.20" version="1.1" xmlns="http://www.w3.org/2000/svg" stroke="' .esc_attr($svg_color) .'"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-9.6" y="-9.6" width="51.20" height="51.20" rx="25.6" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <title>info</title> <path d="M16.247 4.733c0 1.684 1.271 2.825 2.84 2.825s2.842-1.142 2.842-2.825c0-1.685-1.272-2.826-2.842-2.826-1.568 0-2.84 1.141-2.84 2.826zM10.096 14.375c0 0.334-0.061 1.163 0.008 1.662l2.479-2.983c0.513-0.562 1.106-0.955 1.409-0.849s0.47 0.463 0.371 0.795l-4.103 13.59c-0.473 1.588 0.421 3.148 2.599 3.504 3.189 0 5.084-2.158 6.948-4.955 0-0.334 0.111-1.213 0.044-1.713l-2.479 2.982c-0.514 0.562-1.151 0.955-1.455 0.85-0.28-0.098-0.444-0.41-0.389-0.721l4.132-13.653c0.344-1.734-0.59-3.312-2.564-3.514-2.076 0.001-5.136 2.209-7 5.005z"></path> </g></svg>';
                    break;
                case $basics[ 'button_open_svg' ] === 'svg-location':
                    $svg_open = '<svg class="trig-svg-open" viewBox="-7.2 -7.2 38.40 38.40" fill="none" xmlns="http://www.w3.org/2000/svg"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-7.2" y="-7.2" width="38.40" height="38.40" rx="19.2" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <path d="M21.3046 4.69335C21.908 3.41959 20.5806 2.09225 19.3069 2.69561L2.83473 10.4982C1.56185 11.1011 1.74664 12.9674 3.11305 13.309L9.17556 14.8247L10.6912 20.8872C11.0328 22.2536 12.8991 22.4384 13.502 21.1655L21.3046 4.69335Z" fill="' .esc_attr($svg_color) .'"></path> </g></svg>';
                    break;
                case $basics[ 'button_open_svg' ] === 'svg-location-2':
                    $svg_open = '<svg class="trig-svg-open" viewBox="-7.2 -7.2 38.40 38.40" fill="none" xmlns="http://www.w3.org/2000/svg"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-7.2" y="-7.2" width="38.40" height="38.40" rx="19.2" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <g><g> <path fill-rule="evenodd" clip-rule="evenodd" d="M8.89129 21.0787L8.9461 21.1315L8.95039 21.1357C9.95462 22.098 10.9283 22.7576 12.0296 22.7449C13.1259 22.7323 14.0956 22.0555 15.0992 21.0783C16.4747 19.7455 18.2545 17.9477 19.5403 15.8149C20.831 13.6741 21.6639 11.1292 21.0372 8.33595C18.9197 -1.10413 5.09133 -1.11519 2.96276 8.32592C2.35382 11.04 3.12314 13.5227 4.34999 15.6268C5.57222 17.7231 7.2824 19.5029 8.65394 20.8471C8.73386 20.9254 8.81273 21.0023 8.89035 21.0778L8.89129 21.0787ZM12 6.25012C10.2051 6.25012 8.75 7.7052 8.75 9.50012C8.75 11.295 10.2051 12.7501 12 12.7501C13.7949 12.7501 15.25 11.295 15.25 9.50012C15.25 7.7052 13.7949 6.25012 12 6.25012Z" fill="' .esc_attr($svg_color) .'"></path> </g> </g> </g></svg>';
                    break;
                case $basics[ 'button_open_svg' ] === 'svg-mail':
                    $svg_open = '<svg class="trig-svg-open" viewBox="-7.2 -7.2 38.40 38.40" fill="none" xmlns="http://www.w3.org/2000/svg"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-7.2" y="-7.2" width="38.40" height="38.40" rx="19.2" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <path opacity="0.15" d="M21 18V6.00001C21 5.72387 20.8881 5.47387 20.7071 5.29291L20.5 5.50001L13.4142 12.5858C12.6332 13.3668 11.3668 13.3668 10.5858 12.5858L3.5 5.50001L3.29289 5.29291C3.11193 5.47387 3 5.72387 3 6.00001V18C3 18.5523 3.44772 19 4 19H20C20.5523 19 21 18.5523 21 18Z" fill="' .esc_attr($svg_color) .'"></path> <path d="M3.29289 5.29289C3.47386 5.11193 3.72386 5 4 5H20C20.2761 5 20.5261 5.11193 20.7071 5.29289M3.29289 5.29289C3.11193 5.47386 3 5.72386 3 6V18C3 18.5523 3.44772 19 4 19H20C20.5523 19 21 18.5523 21 18V6C21 5.72386 20.8881 5.47386 20.7071 5.29289M3.29289 5.29289L10.5858 12.5858C11.3668 13.3668 12.6332 13.3668 13.4142 12.5858L20.7071 5.29289" stroke="' .esc_attr($svg_color) .'" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round"></path> </g></svg>';
                    break;
                case $basics[ 'button_open_svg' ] === 'svg-pin':
                    $svg_open = '<svg class="trig-svg-open" viewBox="-9.6 -9.6 43.20 43.20" fill="none" xmlns="http://www.w3.org/2000/svg"><g class="SVGRepo_bgCarrier" stroke-width="0" transform="translate(0,0), scale(1)"><rect x="-9.6" y="-9.6" width="43.20" height="43.20" rx="21.6" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <path d="M19.1835 7.80516L16.2188 4.83755C14.1921 2.8089 13.1788 1.79457 12.0904 2.03468C11.0021 2.2748 10.5086 3.62155 9.5217 6.31506L8.85373 8.1381C8.59063 8.85617 8.45908 9.2152 8.22239 9.49292C8.11619 9.61754 7.99536 9.72887 7.86251 9.82451C7.56644 10.0377 7.19811 10.1392 6.46145 10.3423C4.80107 10.8 3.97088 11.0289 3.65804 11.5721C3.5228 11.8069 3.45242 12.0735 3.45413 12.3446C3.45809 12.9715 4.06698 13.581 5.28476 14.8L6.69935 16.2163L2.22345 20.6964C1.92552 20.9946 1.92552 21.4782 2.22345 21.7764C2.52138 22.0746 3.00443 22.0746 3.30236 21.7764L7.77841 17.2961L9.24441 18.7635C10.4699 19.9902 11.0827 20.6036 11.7134 20.6045C11.9792 20.6049 12.2404 20.5358 12.4713 20.4041C13.0192 20.0914 13.2493 19.2551 13.7095 17.5825C13.9119 16.8472 14.013 16.4795 14.2254 16.1835C14.3184 16.054 14.4262 15.9358 14.5468 15.8314C14.8221 15.593 15.1788 15.459 15.8922 15.191L17.7362 14.4981C20.4 13.4973 21.7319 12.9969 21.9667 11.9115C22.2014 10.826 21.1954 9.81905 19.1835 7.80516Z" fill="' .esc_attr($svg_color) .'"></path> </g></svg>';
                    break;
                case $basics[ 'button_open_svg' ] === 'svg-play':
                    $svg_open = '<svg class="trig-svg-open" viewBox="-10.8 -10.8 45.60 45.60" fill="none" xmlns="http://www.w3.org/2000/svg"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-10.8" y="-10.8" width="45.60" height="45.60" rx="22.8" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <path d="M21.4086 9.35258C23.5305 10.5065 23.5305 13.4935 21.4086 14.6474L8.59662 21.6145C6.53435 22.736 4 21.2763 4 18.9671L4 5.0329C4 2.72368 6.53435 1.26402 8.59661 2.38548L21.4086 9.35258Z" fill="' .esc_attr($svg_color) .'"></path> </g></svg>';
                    break;
                case $basics[ 'button_open_svg' ] === 'svg-settings':
                    $svg_open = '<svg class="trig-svg-open" viewBox="-7.2 -7.2 38.40 38.40" fill="none" xmlns="http://www.w3.org/2000/svg"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-7.2" y="-7.2" width="38.40" height="38.40" rx="19.2" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <path d="M12 14.93C11.4205 14.93 10.854 14.7582 10.3722 14.4362C9.89035 14.1143 9.51481 13.6567 9.29304 13.1213C9.07128 12.5859 9.01325 11.9968 9.12631 11.4284C9.23936 10.86 9.51842 10.338 9.92819 9.92819C10.338 9.51842 10.86 9.23936 11.4284 9.12631C11.9968 9.01325 12.5859 9.07128 13.1213 9.29304C13.6567 9.51481 14.1143 9.89035 14.4362 10.3722C14.7582 10.854 14.93 11.4205 14.93 12C14.93 12.7771 14.6213 13.5224 14.0718 14.0718C13.5224 14.6213 12.7771 14.93 12 14.93ZM12 10.57C11.7172 10.57 11.4407 10.6539 11.2055 10.811C10.9704 10.9681 10.7871 11.1915 10.6789 11.4528C10.5706 11.7141 10.5423 12.0016 10.5975 12.279C10.6527 12.5564 10.7889 12.8112 10.9888 13.0112C11.1888 13.2112 11.4436 13.3474 11.721 13.4025C11.9984 13.4577 12.2859 13.4294 12.5472 13.3212C12.8085 13.2129 13.0319 13.0296 13.189 12.7945C13.3461 12.5593 13.43 12.2828 13.43 12C13.43 11.6207 13.2793 11.257 13.0112 10.9888C12.743 10.7207 12.3793 10.57 12 10.57Z" fill="' .esc_attr($svg_color) .'"></path> <path d="M12.06 20.75C11.7676 20.7487 11.4784 20.6896 11.2089 20.5762C10.9394 20.4628 10.6949 20.2973 10.4896 20.0892C10.2842 19.881 10.122 19.6344 10.0123 19.3634C9.90252 19.0924 9.84737 18.8024 9.85001 18.51C9.84606 18.4198 9.81676 18.3326 9.76546 18.2583C9.71416 18.184 9.64295 18.1257 9.56001 18.09C9.46824 18.0479 9.36604 18.034 9.26634 18.05C9.16665 18.066 9.07396 18.1112 9.00001 18.18C8.58482 18.592 8.02493 18.8253 7.44001 18.83C6.8514 18.8338 6.28454 18.6077 5.86001 18.2C5.6538 17.9938 5.49022 17.7491 5.37861 17.4797C5.26701 17.2103 5.20956 16.9216 5.20956 16.63C5.20956 16.3384 5.26701 16.0497 5.37861 15.7803C5.49022 15.5109 5.6538 15.2662 5.86001 15.06C5.93053 14.9957 5.98119 14.9126 6.006 14.8205C6.0308 14.7283 6.02873 14.631 6.00001 14.54C5.95128 14.4556 5.88137 14.3854 5.79719 14.3363C5.71301 14.2872 5.61747 14.2609 5.52001 14.26C4.93163 14.2577 4.36714 14.027 3.94554 13.6166C3.52393 13.2062 3.27815 12.6481 3.26001 12.06C3.26132 11.7685 3.32004 11.48 3.43282 11.2112C3.5456 10.9424 3.71022 10.6984 3.9173 10.4931C4.12437 10.2879 4.36984 10.1255 4.63969 10.0152C4.90953 9.9048 5.19847 9.84868 5.49001 9.85C5.5802 9.84605 5.66746 9.81675 5.74175 9.76545C5.81604 9.71415 5.87436 9.64294 5.91001 9.56C5.95213 9.46823 5.96606 9.36603 5.95004 9.26633C5.93402 9.16664 5.88876 9.07395 5.82001 9C5.40797 8.58481 5.17468 8.02492 5.17001 7.44C5.1649 7.14801 5.21797 6.85792 5.32613 6.58665C5.4343 6.31538 5.59539 6.06836 5.80001 5.86C6.00616 5.65379 6.25092 5.49021 6.52031 5.3786C6.78969 5.267 7.07842 5.20955 7.37001 5.20955C7.6616 5.20955 7.95033 5.267 8.21971 5.3786C8.4891 5.49021 8.73385 5.65379 8.94001 5.86C9.01201 5.9285 9.10041 5.97735 9.19672 6.00187C9.29303 6.02638 9.39402 6.02574 9.49001 6C9.57752 5.95207 9.65169 5.88308 9.70582 5.79927C9.75995 5.71546 9.79232 5.61947 9.80001 5.52C9.79973 4.92989 10.0293 4.36287 10.4399 3.93912C10.8506 3.51537 11.4102 3.2682 12 3.25C12.2915 3.25261 12.5797 3.31263 12.8481 3.42662C13.1164 3.5406 13.3597 3.70633 13.564 3.91434C13.7682 4.12234 13.9296 4.36855 14.0387 4.63891C14.1478 4.90926 14.2026 5.19846 14.2 5.49C14.2038 5.5815 14.2317 5.67038 14.2809 5.74764C14.33 5.8249 14.3987 5.88781 14.48 5.93C14.5683 5.96241 14.6639 5.96927 14.7558 5.94982C14.8478 5.93036 14.9324 5.88537 15 5.82C15.4152 5.40796 15.9751 5.17467 16.56 5.17C16.8525 5.16083 17.1438 5.21204 17.4156 5.32044C17.6875 5.42883 17.9341 5.59208 18.14 5.8C18.3462 6.00615 18.5098 6.25091 18.6214 6.5203C18.733 6.78968 18.7905 7.07841 18.7905 7.37C18.7905 7.66159 18.733 7.95032 18.6214 8.2197C18.5098 8.48909 18.3462 8.73385 18.14 8.94C18.0767 9.01489 18.0333 9.10463 18.0141 9.20082C17.9949 9.29701 18.0003 9.3965 18.03 9.49C18.0779 9.57751 18.1469 9.65168 18.2307 9.70581C18.3145 9.75994 18.4105 9.79231 18.51 9.8C19.0949 9.80745 19.6544 10.0404 20.0717 10.4503C20.489 10.8602 20.732 11.4153 20.75 12C20.7474 12.2915 20.6874 12.5797 20.5734 12.848C20.4594 13.1164 20.2937 13.3597 20.0857 13.5639C19.8777 13.7682 19.6315 13.9296 19.3611 14.0387C19.0907 14.1478 18.8015 14.2026 18.51 14.2C18.4185 14.2038 18.3296 14.2317 18.2524 14.2809C18.1751 14.33 18.1122 14.3987 18.07 14.48C18.0376 14.5683 18.0307 14.6638 18.0502 14.7558C18.0696 14.8478 18.1146 14.9324 18.18 15C18.5921 15.4152 18.8253 15.9751 18.83 16.56C18.8351 16.852 18.782 17.1421 18.6739 17.4133C18.5657 17.6846 18.4046 17.9316 18.2 18.14C17.9939 18.3462 17.7491 18.5098 17.4797 18.6214C17.2103 18.733 16.9216 18.7904 16.63 18.7904C16.3384 18.7904 16.0497 18.733 15.7803 18.6214C15.5109 18.5098 15.2662 18.3462 15.06 18.14C14.9924 18.0746 14.9078 18.0296 14.8158 18.0102C14.7239 17.9907 14.6283 17.9976 14.54 18.03C14.4556 18.0787 14.3854 18.1486 14.3363 18.2328C14.2872 18.317 14.2609 18.4125 14.26 18.51C14.2526 19.0949 14.0196 19.6544 13.6097 20.0717C13.1998 20.489 12.6447 20.732 12.06 20.75ZM9.35001 16.54C9.61524 16.5369 9.87797 16.5915 10.12 16.7C10.4772 16.8489 10.7835 17.0982 11.0018 17.4177C11.2202 17.7372 11.3411 18.1131 11.35 18.5C11.3472 18.6929 11.4199 18.8792 11.5525 19.0193C11.6852 19.1594 11.8673 19.2422 12.06 19.25C12.2527 19.2348 12.4324 19.1466 12.5625 19.0036C12.6925 18.8605 12.7632 18.6733 12.76 18.48C12.7624 18.0918 12.8744 17.7121 13.0832 17.3848C13.292 17.0575 13.589 16.7958 13.94 16.63C14.3052 16.4781 14.7072 16.4379 15.0952 16.5144C15.4832 16.5909 15.8399 16.7808 16.12 17.06C16.2526 17.1926 16.4325 17.2671 16.62 17.2671C16.8075 17.2671 16.9874 17.1926 17.12 17.06C17.2526 16.9274 17.3271 16.7475 17.3271 16.56C17.3271 16.3725 17.2526 16.1926 17.12 16.06C16.8425 15.7788 16.6545 15.4216 16.5798 15.0336C16.505 14.6456 16.5469 14.2442 16.7 13.88C16.8577 13.5291 17.1133 13.2311 17.4362 13.0218C17.759 12.8126 18.1353 12.7008 18.52 12.7C18.7103 12.7028 18.8941 12.6311 19.0323 12.5004C19.1705 12.3696 19.2522 12.1901 19.26 12C19.2472 11.8064 19.1597 11.6253 19.0162 11.4947C18.8726 11.3642 18.684 11.2944 18.49 11.3C18.0986 11.2894 17.7179 11.1695 17.391 10.9539C17.0641 10.7383 16.804 10.4356 16.64 10.08C16.4903 9.71114 16.4513 9.30669 16.5277 8.91602C16.604 8.52535 16.7925 8.16536 17.07 7.88C17.1357 7.81434 17.1878 7.73639 17.2233 7.6506C17.2588 7.56481 17.2771 7.47286 17.2771 7.38C17.2771 7.28714 17.2588 7.19519 17.2233 7.1094C17.1878 7.02361 17.1357 6.94566 17.07 6.88C17.0043 6.81434 16.9264 6.76225 16.8406 6.72672C16.7548 6.69118 16.6629 6.67289 16.57 6.67289C16.4772 6.67289 16.3852 6.69118 16.2994 6.72672C16.2136 6.76225 16.1357 6.81434 16.07 6.88C15.7889 7.14113 15.4385 7.31587 15.0608 7.38337C14.6831 7.45088 14.2939 7.4083 13.9397 7.26072C13.5855 7.11314 13.2812 6.86679 13.0632 6.55105C12.8452 6.2353 12.7226 5.86351 12.71 5.48C12.7128 5.28976 12.6412 5.10595 12.5104 4.96773C12.3797 4.82951 12.2001 4.7478 12.01 4.74C11.8164 4.75286 11.6353 4.84026 11.5047 4.98385C11.3742 5.12744 11.3044 5.31603 11.31 5.51C11.2994 5.90145 11.1795 6.28212 10.9639 6.60903C10.7483 6.93593 10.4456 7.19605 10.09 7.36C9.72115 7.50966 9.3167 7.54869 8.92603 7.47233C8.53536 7.39598 8.17537 7.20753 7.89001 6.93C7.82435 6.86434 7.7464 6.81225 7.66061 6.77672C7.57482 6.74118 7.48287 6.72289 7.39001 6.72289C7.29715 6.72289 7.2052 6.74118 7.11941 6.77672C7.03362 6.81225 6.95567 6.86434 6.89001 6.93C6.82435 6.99566 6.77226 7.07361 6.73673 7.1594C6.70119 7.24519 6.6829 7.33714 6.6829 7.43C6.6829 7.52286 6.70119 7.61481 6.73673 7.7006C6.77226 7.78639 6.82435 7.86434 6.89001 7.93C7.16585 8.21235 7.35197 8.57002 7.42493 8.95795C7.49789 9.34588 7.45443 9.74673 7.30001 10.11C7.15113 10.4672 6.90183 10.7735 6.58234 10.9918C6.26284 11.2101 5.88687 11.3311 5.50001 11.34C5.30712 11.3372 5.12077 11.4099 4.98067 11.5425C4.84058 11.6752 4.75781 11.8572 4.75001 12.05C4.76525 12.2427 4.85336 12.4224 4.99641 12.5525C5.13947 12.6825 5.3267 12.7531 5.52001 12.75C5.90823 12.7524 6.28788 12.8644 6.6152 13.0732C6.94251 13.282 7.20417 13.579 7.37001 13.93C7.52192 14.2952 7.56215 14.6972 7.48561 15.0852C7.40907 15.4732 7.2192 15.8299 6.94001 16.11C6.87435 16.1757 6.82226 16.2536 6.78673 16.3394C6.75119 16.4252 6.7329 16.5171 6.7329 16.61C6.7329 16.7029 6.75119 16.7948 6.78673 16.8806C6.82226 16.9664 6.87435 17.0443 6.94001 17.11C7.00567 17.1757 7.08362 17.2277 7.16941 17.2633C7.2552 17.2988 7.34715 17.3171 7.44001 17.3171C7.53287 17.3171 7.62482 17.2988 7.71061 17.2633C7.7964 17.2277 7.87435 17.1757 7.94001 17.11C8.3201 16.7471 8.82451 16.5432 9.35001 16.54Z" fill="' .esc_attr($svg_color) .'"></path> </g></svg>';
                    break;
                case $basics[ 'button_open_svg' ] === 'svg-share':
                    $svg_open = '<svg class="trig-svg-open" viewBox="-8.4 -8.4 40.80 40.80" fill="none" xmlns="http://www.w3.org/2000/svg"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-8.4" y="-8.4" width="40.80" height="40.80" rx="20.4" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <path d="M9 11.5C9 12.8807 7.88071 14 6.5 14C5.11929 14 4 12.8807 4 11.5C4 10.1193 5.11929 9 6.5 9C7.88071 9 9 10.1193 9 11.5Z" stroke="' .esc_attr($svg_color) .'" stroke-width="1.5"></path> <path opacity="0.5" d="M14.3206 16.8017L9 13.29" stroke="' .esc_attr($svg_color) .'" stroke-width="1.5" stroke-linecap="round"></path> <path opacity="0.5" d="M14.4207 6.83984L9.1001 10.3515" stroke="' .esc_attr($svg_color) .'" stroke-width="1.5" stroke-linecap="round"></path> <path d="M19 18.5C19 19.8807 17.8807 21 16.5 21C15.1193 21 14 19.8807 14 18.5C14 17.1193 15.1193 16 16.5 16C17.8807 16 19 17.1193 19 18.5Z" stroke="' .esc_attr($svg_color) .'" stroke-width="1.5"></path> <path d="M19 5.5C19 6.88071 17.8807 8 16.5 8C15.1193 8 14 6.88071 14 5.5C14 4.11929 15.1193 3 16.5 3C17.8807 3 19 4.11929 19 5.5Z" stroke="' .esc_attr($svg_color) .'" stroke-width="1.5"></path> </g></svg>';
                    break;
                case $basics[ 'button_open_svg' ] === 'svg-share-2':
                    $svg_open = '<svg class="trig-svg-open" viewBox="-8.4 -8.4 40.80 40.80" fill="none" xmlns="http://www.w3.org/2000/svg"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-8.4" y="-8.4" width="40.80" height="40.80" rx="20.4" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <g opacity="0.5"> <path d="M7.20468 7.56232C7.51523 7.28822 7.54478 6.81427 7.27069 6.50371C6.99659 6.19316 6.52264 6.1636 6.21208 6.4377C4.39676 8.03992 3.25 10.3865 3.25 13C3.25 13.4142 3.58579 13.75 4 13.75C4.41421 13.75 4.75 13.4142 4.75 13C4.75 10.8347 5.69828 8.89188 7.20468 7.56232Z" fill="' .esc_attr($svg_color) .'"></path> <path d="M17.7879 6.4377C17.4774 6.1636 17.0034 6.19316 16.7293 6.50371C16.4552 6.81427 16.4848 7.28822 16.7953 7.56232C18.3017 8.89188 19.25 10.8347 19.25 13C19.25 13.4142 19.5858 13.75 20 13.75C20.4142 13.75 20.75 13.4142 20.75 13C20.75 10.3865 19.6032 8.03992 17.7879 6.4377Z" fill="' .esc_attr($svg_color) .'"></path> <path d="M10.1869 20.0217C9.7858 19.9184 9.37692 20.1599 9.27367 20.5611C9.17043 20.9622 9.41192 21.3711 9.81306 21.4743C10.5129 21.6544 11.2458 21.75 12 21.75C12.7542 21.75 13.4871 21.6544 14.1869 21.4743C14.5881 21.3711 14.8296 20.9622 14.7263 20.5611C14.6231 20.1599 14.2142 19.9184 13.8131 20.0217C13.2344 20.1706 12.627 20.25 12 20.25C11.373 20.25 10.7656 20.1706 10.1869 20.0217Z" fill="' .esc_attr($svg_color) .'"></path> </g> <path d="M9 6C9 7.65685 10.3431 9 12 9C13.6569 9 15 7.65685 15 6C15 4.34315 13.6569 3 12 3C10.3431 3 9 4.34315 9 6Z" fill="' .esc_attr($svg_color) .'"></path> <path d="M2.5 18C2.5 19.6569 3.84315 21 5.5 21C7.15685 21 8.5 19.6569 8.5 18C8.5 16.3431 7.15685 15 5.5 15C3.84315 15 2.5 16.3431 2.5 18Z" fill="' .esc_attr($svg_color) .'"></path> <path d="M18.5 21C16.8431 21 15.5 19.6569 15.5 18C15.5 16.3431 16.8431 15 18.5 15C20.1569 15 21.5 16.3431 21.5 18C21.5 19.6569 20.1569 21 18.5 21Z" fill="' .esc_attr($svg_color) .'"></path> </g></svg>';
                    break;
                case $basics[ 'button_open_svg' ] === 'svg-plus':
                    $svg_open = '<svg class="trig-svg-open" viewBox="0 0 32.00 32.00" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" xmlns:sketch="http://www.bohemiancoding.com/sketch/ns" fill="' .esc_attr($svg_bg) .'"><g class="SVGRepo_bgCarrier" stroke-width="0" transform="translate(6.4,6.4), scale(0.6)"><rect x="0" y="0" width="32.00" height="32.00" rx="0" fill="' .esc_attr($svg_color) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <title>plus-square</title> <desc>Created with Sketch Beta.</desc> <defs> </defs> <g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd" sketch:type="MSPage"> <g sketch:type="MSLayerGroup" transform="translate(-102.000000, -1037.000000)" fill="' .esc_attr($svg_bg) .'"> <path d="M124,1054 L119,1054 L119,1059 C119,1059.55 118.552,1060 118,1060 C117.448,1060 117,1059.55 117,1059 L117,1054 L112,1054 C111.448,1054 111,1053.55 111,1053 C111,1052.45 111.448,1052 112,1052 L117,1052 L117,1047 C117,1046.45 117.448,1046 118,1046 C118.552,1046 119,1046.45 119,1047 L119,1052 L124,1052 C124.552,1052 125,1052.45 125,1053 C125,1053.55 124.552,1054 124,1054 L124,1054 Z M130,1037 L106,1037 C103.791,1037 102,1038.79 102,1041 L102,1065 C102,1067.21 103.791,1069 106,1069 L130,1069 C132.209,1069 134,1067.21 134,1065 L134,1041 C134,1038.79 132.209,1037 130,1037 L130,1037 Z" sketch:type="MSShapeGroup"> </path> </g> </g> </g></svg>';
                    break;
                case $basics[ 'button_open_svg' ] === 'svg-plus-2':
                    $svg_open = '<svg class="trig-svg-open" viewBox="-0.64 -0.64 33.28 33.28" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" xmlns:sketch="http://www.bohemiancoding.com/sketch/ns" fill="' .esc_attr($svg_bg) .'"><g class="SVGRepo_bgCarrier" stroke-width="0" transform="translate(1.92,1.92), scale(0.88)"><rect x="-0.64" y="-0.64" width="33.28" height="33.28" rx="16.64" fill="' .esc_attr($svg_color) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <title>plus-circle</title> <desc>Created with Sketch Beta.</desc> <defs> </defs> <g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd" sketch:type="MSPage"> <g sketch:type="MSLayerGroup" transform="translate(-466.000000, -1089.000000)" fill="' .esc_attr($svg_bg) .'"> <path d="M488,1106 L483,1106 L483,1111 C483,1111.55 482.553,1112 482,1112 C481.447,1112 481,1111.55 481,1111 L481,1106 L476,1106 C475.447,1106 475,1105.55 475,1105 C475,1104.45 475.447,1104 476,1104 L481,1104 L481,1099 C481,1098.45 481.447,1098 482,1098 C482.553,1098 483,1098.45 483,1099 L483,1104 L488,1104 C488.553,1104 489,1104.45 489,1105 C489,1105.55 488.553,1106 488,1106 L488,1106 Z M482,1089 C473.163,1089 466,1096.16 466,1105 C466,1113.84 473.163,1121 482,1121 C490.837,1121 498,1113.84 498,1105 C498,1096.16 490.837,1089 482,1089 L482,1089 Z" sketch:type="MSShapeGroup"> </path> </g> </g> </g></svg>';
                    break;
                }
            }

            $svg_close = '';
            if (! empty($basics[ 'button_close_svg' ]) ) {
                switch ( $basics[ 'button_close_svg' ] ) {
                case $basics[ 'button_close_svg' ] === 'svg-app':
                    $svg_close = '<svg class="trig-svg-close" fill="' .esc_attr($svg_color) .'" height="200px" width="200px" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="-2.4 -2.4 28.80 28.80" enable-background="new 0 0 24 24" xml:space="preserve" stroke="' .esc_attr($svg_color) .'"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-2.4" y="-2.4" width="28.80" height="28.80" rx="0" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <g> <path d="M6,6H2V2h4V6z M14,2h-4v4h4V2z M22,2h-4v4h4V2z M6,10H2v4h4V10z M14,10h-4v4h4V10z M22,10h-4v4h4V10z M6,18H2v4h4V18z M14,18h-4v4h4V18z M22,18h-4v4h4V18z"></path> </g> </g></svg>';
                    break;
                case $basics[ 'button_close_svg' ] === 'svg-app-2':
                    $svg_close = '<svg class="trig-svg-close" fill="' .esc_attr($svg_color) .'" viewBox="-2.4 -2.4 28.80 28.80" xmlns="http://www.w3.org/2000/svg" stroke="' .esc_attr($svg_color) .'" stroke-width="0.00024000000000000003"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-2.4" y="-2.4" width="28.80" height="28.80" rx="0" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <path fill-rule="evenodd" d="M20,22 C18.8954305,22 18,21.1045695 18,20 C18,18.8954305 18.8954305,18 20,18 C21.1045695,18 22,18.8954305 22,20 C22,21.1045695 21.1045695,22 20,22 Z M20,14 C18.8954305,14 18,13.1045695 18,12 C18,10.8954305 18.8954305,10 20,10 C21.1045695,10 22,10.8954305 22,12 C22,13.1045695 21.1045695,14 20,14 Z M20,6 C18.8954305,6 18,5.1045695 18,4 C18,2.8954305 18.8954305,2 20,2 C21.1045695,2 22,2.8954305 22,4 C22,5.1045695 21.1045695,6 20,6 Z M12,22 C10.8954305,22 10,21.1045695 10,20 C10,18.8954305 10.8954305,18 12,18 C13.1045695,18 14,18.8954305 14,20 C14,21.1045695 13.1045695,22 12,22 Z M12,14 C10.8954305,14 10,13.1045695 10,12 C10,10.8954305 10.8954305,10 12,10 C13.1045695,10 14,10.8954305 14,12 C14,13.1045695 13.1045695,14 12,14 Z M12,6 C10.8954305,6 10,5.1045695 10,4 C10,2.8954305 10.8954305,2 12,2 C13.1045695,2 14,2.8954305 14,4 C14,5.1045695 13.1045695,6 12,6 Z M4,22 C2.8954305,22 2,21.1045695 2,20 C2,18.8954305 2.8954305,18 4,18 C5.1045695,18 6,18.8954305 6,20 C6,21.1045695 5.1045695,22 4,22 Z M4,14 C2.8954305,14 2,13.1045695 2,12 C2,10.8954305 2.8954305,10 4,10 C5.1045695,10 6,10.8954305 6,12 C6,13.1045695 5.1045695,14 4,14 Z M4,6 C2.8954305,6 2,5.1045695 2,4 C2,2.8954305 2.8954305,2 4,2 C5.1045695,2 6,2.8954305 6,4 C6,5.1045695 5.1045695,6 4,6 Z"></path> </g></svg>';
                    break;
                case $basics[ 'button_close_svg' ] === 'svg-app-3':
                    $svg_close = '<svg class="trig-svg-close" viewBox="-7.2 -7.2 38.40 38.40" xmlns="http://www.w3.org/2000/svg" fill="' .esc_attr($svg_color) .'"><g id="SVGRepo_bgCarrier" stroke-width="0"><rect x="-7.2" y="-7.2" width="38.40" height="38.40" rx="19.2" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g id="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g id="SVGRepo_iconCarrier"><path d="M5.5 4A1.5 1.5 0 1 1 4 2.5 1.5 1.5 0 0 1 5.5 4zM12 2.5A1.5 1.5 0 1 0 13.5 4 1.5 1.5 0 0 0 12 2.5zm8 0A1.5 1.5 0 1 0 21.5 4 1.5 1.5 0 0 0 20 2.5zm-16 8A1.5 1.5 0 1 0 5.5 12 1.5 1.5 0 0 0 4 10.5zm8 0a1.5 1.5 0 1 0 1.5 1.5 1.5 1.5 0 0 0-1.5-1.5zm8 0a1.5 1.5 0 1 0 1.5 1.5 1.5 1.5 0 0 0-1.5-1.5zm-16 8A1.5 1.5 0 1 0 5.5 20 1.5 1.5 0 0 0 4 18.5zm8 0a1.5 1.5 0 1 0 1.5 1.5 1.5 1.5 0 0 0-1.5-1.5zm8 0a1.5 1.5 0 1 0 1.5 1.5 1.5 1.5 0 0 0-1.5-1.5z"></path><path fill="none" d="M0 0h24v24H0z"></path></g></svg>';
                    break;
                case $basics[ 'button_close_svg' ] === 'svg-basket':
                    $svg_close = '<svg class="trig-svg-close" fill="' .esc_attr($svg_color) .'" viewBox="-172.8 -172.8 921.60 921.60" xmlns="http://www.w3.org/2000/svg" stroke="' .esc_attr($svg_color) .'"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-172.8" y="-172.8" width="921.60" height="921.60" rx="460.8" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"><path d="M576 216v16c0 13.255-10.745 24-24 24h-8l-26.113 182.788C514.509 462.435 494.257 480 470.37 480H105.63c-23.887 0-44.139-17.565-47.518-41.212L32 256h-8c-13.255 0-24-10.745-24-24v-16c0-13.255 10.745-24 24-24h67.341l106.78-146.821c10.395-14.292 30.407-17.453 44.701-7.058 14.293 10.395 17.453 30.408 7.058 44.701L170.477 192h235.046L326.12 82.821c-10.395-14.292-7.234-34.306 7.059-44.701 14.291-10.395 34.306-7.235 44.701 7.058L484.659 192H552c13.255 0 24 10.745 24 24zM312 392V280c0-13.255-10.745-24-24-24s-24 10.745-24 24v112c0 13.255 10.745 24 24 24s24-10.745 24-24zm112 0V280c0-13.255-10.745-24-24-24s-24 10.745-24 24v112c0 13.255 10.745 24 24 24s24-10.745 24-24zm-224 0V280c0-13.255-10.745-24-24-24s-24 10.745-24 24v112c0 13.255 10.745 24 24 24s24-10.745 24-24z"></path></g></svg>';
                    break;
                case $basics[ 'button_close_svg' ] === 'svg-basket-x':
                    $svg_close = '<svg class="trig-svg-close" fill="' .esc_attr($svg_color) .'" height="200px" width="200px" version="1.1 xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="-9.6 -9.6 51.20 51.20" xml:space="preserve" stroke="' .esc_attr($svg_color) .'"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-9.6" y="-9.6" width="51.20" height="51.20" rx="25.6" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <path d="M29,13h-2h-4.5l2.6-6.1c0.3-0.6,0.3-1.4-0.1-1.9S24.1,4,23.4,4h-7.1c-1.1,0-2.2,0.6-2.7,1.7L10.3,13H5H3c-0.6,0-1,0.4-1,1 s0.4,1,1,1h1.1l1.5,9.6c0.3,2,2,3.4,4,3.4h12.9c2,0,3.7-1.4,4-3.4l1.5-9.6H29c0.6,0,1-0.4,1-1S29.6,13,29,13z M18.8,21.4 c0.4,0.4,0.4,1,0,1.4c-0.2,0.2-0.5,0.3-0.7,0.3s-0.5-0.1-0.7-0.3L16,21.4l-1.4,1.4c-0.2,0.2-0.5,0.3-0.7,0.3s-0.5-0.1-0.7-0.3 c-0.4-0.4-0.4-1,0-1.4l1.4-1.4l-1.4-1.4c-0.4-0.4-0.4-1,0-1.4c0.4-0.4,1-0.4,1.4,0l1.4,1.4l1.4-1.4c0.4-0.4,1-0.4,1.4,0 c0.4,0.4,0.4,1,0,1.4L17.4,20L18.8,21.4z M20.3,13h-7.8l2.8-6.4C15.5,6.2,15.9,6,16.2,6l7.1,0L20.3,13z"></path> </g></svg>';
                    break;
                case $basics[ 'button_close_svg' ] === 'svg-basket--':
                    $svg_close = '<svg class="trig-svg-close" fill="' .esc_attr($svg_color) .'" viewBox="-9.3 -9.3 49.60 49.60" xmlns="http://www.w3.org/2000/svg" stroke="' .esc_attr($svg_color) .'"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-9.3" y="-9.3" width="49.60" height="49.60" rx="24.8" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"><path d="m19.479 22.099q0-.046 0-.091h-5.729q0 .045 0 .091c0 1.05-.851 1.901-1.901 1.901s-1.901-.851-1.901-1.901q0-.046 0-.091h-.651c-.585 0-1.073-.411-1.193-.96l-.001-.008-3.817-18.073-3.261-.543c-.56-.119-.974-.609-.974-1.196 0-.674.547-1.221 1.221-1.221.053 0 .105.003.157.01l-.006-.001 4.081.68c.497.085.887.461.991.943l.001.008.692 3.264 11.904.992c-.07.356-.11.766-.112 1.186v.001.001c0 .381.032.754.092 1.118l-.005-.039c-.29.112-.523.32-.663.585l-.003.007c-.117.213-.186.467-.186.738 0 .077.006.153.016.227l-.001-.008.719 5.19c.044.333.196.625.418.845.202.201.48.326.786.33h.001c.068 0 .135-.007.199-.019l-.007.001c.601-.16 1.038-.699 1.038-1.341 0-.09-.009-.179-.025-.264l.001.009-.36-2.592c1.201 1.185 2.852 1.917 4.674 1.917h.002c.043 0 .086 0 .128-.006h.092l-.669 3.902c-.034.193-.2.338-.4.338-.001 0-.001 0-.002 0h-14.867l.327 1.547h14.157c.011 0 .023-.001.036-.001.674 0 1.221.547 1.221 1.221s-.547 1.221-1.221 1.221c-.013 0-.025 0-.038-.001h.002-1.164q0 .045 0 .091c-.025 1.031-.866 1.856-1.901 1.856s-1.876-.826-1.901-1.854v-.002zm1.358 0c.005.294.245.53.539.53.298 0 .539-.241.539-.539 0-.029-.002-.057-.007-.085v.003h-1.063c-.005.027-.007.057-.007.089v.002zm-9.528 0c.001.297.242.537.539.537s.539-.241.539-.539c0-.031-.003-.062-.008-.092v.003h-1.062c-.005.027-.007.057-.007.089v.002zm3.972-13.972c-.603.159-1.04.699-1.04 1.341 0 .089.008.176.024.26l-.001-.009.719 5.19c.044.333.196.625.418.845.202.201.479.327.786.33h.001c.068 0 .135-.007.199-.019l-.007.001c.602-.159 1.039-.699 1.039-1.341 0-.09-.009-.178-.025-.264l.001.009-.719-5.19c-.044-.333-.196-.625-.418-.845-.203-.2-.482-.325-.79-.326-.067 0-.132.006-.196.018l.007-.001zm-3.967 0c-.602.159-1.039.698-1.039 1.34 0 .089.008.177.025.261l-.001-.009.719 5.19c.044.333.196.625.418.845.202.201.48.326.786.33h.001c.068 0 .135-.007.199-.019l-.007.001c.601-.16 1.038-.699 1.038-1.341 0-.09-.009-.179-.025-.264l.001.009-.72-5.185c-.044-.333-.196-.625-.418-.845-.202-.202-.479-.327-.786-.331h-.001s-.001 0-.002 0c-.067 0-.133.006-.196.018l.007-.001zm8.684-1.032c0-3.136 2.542-5.678 5.678-5.678s5.678 2.542 5.678 5.678-2.542 5.677-5.677 5.678c-3.136-.002-5.678-2.543-5.681-5.678zm1.627 0c0 2.238 1.814 4.052 4.052 4.052s4.052-1.814 4.052-4.052-1.814-4.052-4.052-4.052c-2.238.001-4.052 1.814-4.054 4.052zm2.43.813c-.449 0-.814-.364-.814-.814s.364-.814.814-.814h3.24c.449 0 .814.364.814.814s-.364.814-.814.814z"></path></g></svg>';
                    break;
                case $basics[ 'button_close_svg' ] === 'svg-book':
                    $svg_close = '<svg class="trig-svg-close" version="1.0" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="-32 -32 128.00 128.00" enable-background="new 0 0 64 64" xml:space="preserve" fill="' .esc_attr($svg_bg) .'"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-32" y="-32" width="128.00" height="128.00" rx="64" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <path fill="' .esc_attr($svg_color) .'" d="M60,52V4c0-2.211-1.789-4-4-4H14v51v3h42v8H10c-2.209,0-4-1.791-4-4s1.791-4,4-4h2v-3V0H8 C5.789,0,4,1.789,4,4v54c0,3.313,2.687,6,6,6h49c0.553,0,1-0.447,1-1s-0.447-1-1-1h-1v-8C59.104,54,60,53.104,60,52z M23,14h12 c0.553,0,1,0.447,1,1s-0.447,1-1,1H23c-0.553,0-1-0.447-1-1S22.447,14,23,14z M42,28H23c-0.553,0-1-0.447-1-1s0.447-1,1-1h19 c0.553,0,1,0.447,1,1S42.553,28,42,28z M49,22H23c-0.553,0-1-0.447-1-1s0.447-1,1-1h26c0.553,0,1,0.447,1,1S49.553,22,49,22z"></path> </g></svg>';
                    break;
                case $basics[ 'button_close_svg' ] === 'svg-cookie':
                    $svg_close = '<svg class="trig-svg-close" viewBox="-4.35 -4.35 23.70 23.70" fill="none" xmlns="http://www.w3.org/2000/svg"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-4.35" y="-4.35" width="23.70" height="23.70" rx="11.85" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <path fill-rule="evenodd" clip-rule="evenodd" d="M12.0697 1.76746C12.4807 1.21947 11.4605 0.454311 11.0495 1.0023C10.6385 1.55028 11.6588 2.31544 12.0697 1.76746ZM8.39263 1.07811C7.15585 0.950602 5.7823 1.16348 4.58433 1.70937C3.38552 2.25563 2.32735 3.15309 1.78844 4.41832C1.37574 5.38724 1.01715 6.28113 1.00088 7.44354C0.984724 8.59844 1.30522 9.96898 2.13174 11.928C2.61142 13.0649 4.03963 13.5446 5.13895 13.8079C6.40836 14.1119 7.80857 14.1914 8.6644 14.0742C9.36515 13.9782 10.1448 13.8284 10.7987 13.297C11.8977 12.4039 12.9009 11.3955 13.4994 10.3393C14.104 9.27221 14.3256 8.09207 13.7216 6.95324C13.5628 6.65373 13.316 6.57734 13.0412 6.4923C12.9374 6.46016 12.8295 6.42678 12.7209 6.37966C11.6211 5.90234 10.9646 5.34963 10.9135 5.02876C10.8656 4.72808 10.9221 4.51463 10.9811 4.29181C11.0129 4.17199 11.0453 4.04947 11.0626 3.90922C11.0838 3.73737 11.0814 3.33319 10.6996 3.12761C10.4048 2.96888 10.2164 2.65843 10.0407 2.36904C9.99742 2.29775 9.95492 2.22773 9.9118 2.16158C9.62634 1.72367 9.20769 1.16213 8.39263 1.07811ZM4.99899 2.61935C3.96483 3.09058 3.12554 3.83097 2.70846 4.81018C2.29808 5.77368 2.01406 6.50873 2.00079 7.45753C1.98741 8.41385 2.25043 9.6368 3.0531 11.5393C3.39181 12.3421 4.62167 12.6557 5.37186 12.8354C6.5493 13.1174 7.822 13.1802 8.52868 13.0834C9.21271 12.9897 9.74568 12.8642 10.1681 12.5209C11.229 11.6587 12.121 10.7435 12.6293 9.84635C12.9349 9.30709 13.5141 7.7028 12.6292 7.3873C10.7539 6.71875 10.262 6.06669 9.99011 5.41268C9.80915 4.97744 9.82868 4.52282 9.95741 4.07885L9.95741 4.07884C9.97662 4.0126 9.99538 3.94791 10.0334 3.88882C9.81857 3.73676 9.6515 3.55195 9.51464 3.3715C9.42876 3.25828 9.3469 3.12099 9.26197 2.97856C9.01866 2.57052 8.75018 2.12027 8.29008 2.07283C7.22889 1.96343 6.03398 2.14772 4.99899 2.61935ZM13.2081 3.77471C13.441 3.22671 12.4547 2.63606 12.0822 3.10163C11.5817 3.72732 12.9029 4.49281 13.2081 3.77471ZM14.3672 2.26031C14.9668 2.27493 15.1551 1.11603 14.5718 0.949371C13.8076 0.731026 13.5918 2.24139 14.3672 2.26031ZM14.2857 5.09098C14.8644 5.10004 15.0462 4.38222 14.4832 4.27899C13.7455 4.14375 13.5373 5.07927 14.2857 5.09098ZM6.9075 4.28672C6.46898 4.66754 6.0522 4.15185 5.97983 3.7365C5.86848 3.09744 6.33696 2.56856 6.94823 2.91156C7.43344 3.18382 7.26678 3.97471 6.9075 4.28672ZM4.94455 5.88184C5.40885 5.41754 4.59567 4.57013 4.11425 5.05154C3.83338 5.33242 4.00936 5.65376 4.23744 5.88184C4.43271 6.0771 4.74929 6.0771 4.94455 5.88184ZM6.97716 6.71984C7.31181 7.38914 8.48804 6.79159 7.99413 6.14788C7.86519 5.97983 7.68657 5.9494 7.62145 5.94207C7.21217 5.89601 6.76349 6.2925 6.97716 6.71984ZM6.98798 8.72461C7.14066 9.1188 7.51122 9.3187 7.91915 9.1633C8.27434 9.02799 8.33186 8.39689 8.17175 8.07427C8.02331 7.77514 7.63956 7.67793 7.33747 7.79417C6.98512 7.92976 6.85672 8.38708 6.98576 8.71889L6.98798 8.72461ZM10.3885 8.84081C10.7575 8.6566 11.4617 8.82771 11.4617 9.31199C11.4617 9.71286 10.9587 10.2165 10.5634 10.2826C10.1813 10.3465 9.70515 9.97581 9.76648 9.57718C9.81445 9.26539 10.1217 8.97401 10.3885 8.84081ZM7.56704 10.8432C7.33461 10.7502 7.14353 10.8601 7.11437 10.8769L7.11279 10.8778C6.90782 10.9949 6.71383 11.2439 6.6747 11.4842C6.59018 12.0034 7.13199 12.1239 7.52661 12.0987C8.2074 12.0553 8.06547 11.0426 7.56704 10.8432ZM4.8805 10.8932C5.0674 10.7723 5.15658 10.5363 5.08293 10.3153C4.93046 9.79687 4.3246 9.71252 3.96561 10.1297C3.79336 10.3299 3.80749 10.6274 3.99214 10.8105L3.99495 10.814L3.9979 10.8176C4.22025 11.0942 4.63624 11.1857 4.8805 10.8932ZM3.04695 7.81318C3.33147 8.0977 3.60077 8.15067 3.98443 8.05859C4.60826 7.90887 4.13814 6.24299 3.047 6.87296C2.70939 7.06788 2.86716 7.63339 3.04695 7.81318Z" fill="' .esc_attr($svg_color) .'"></path> </g></svg>';
                    break;
                case $basics[ 'button_close_svg' ] === 'svg-cookie-2':
                    $svg_close = '<svg class="trig-svg-close"  fill="' .esc_attr($svg_color) .'" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="-270.06 -270.06 1440.32 1440.32" xml:space="preserve" stroke="' .esc_attr($svg_color) .'"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-270.06" y="-270.06" width="1440.32" height="1440.32" rx="720.16" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <g> <g> <path d="M219.1,515.652c0-6.7,0.4-13.3,1-19.8c-93-27.101-161.8-88.4-161.8-159.7c0-13.8,0.4-37.7,1.1-39.9 c21.2,52.5,100.6,94.3,193.3,109.2l46.7-74.6c10.101-16.1,22.601-30.5,37.3-42.9c14.101-11.9,30.2-22.1,48-30.2 c21.301-9.7,44.5-16.4,69.5-20.1c-2.599-3.6-4.199-8-4.199-12.8c0-12,10-22,22-22s22,10,22,22c0,3.4-0.801,6.7-2.199,9.6 c3.1-0.1,6.1-0.1,9.199-0.1c48.801,0,100,10.3,149.9,29.8c-0.701-121.9-146.201-221-325.4-221c-179.601,0-325.4,99.8-325.4,222.1 l-0.1,97.3c0,98.6,94.9,182,225.8,210.6C221.3,553.652,219,534.452,219.1,515.652z M432.5,107.952c12,0,22,10,22,22s-10,22-22,22 s-22-10-22-22S420.4,107.952,432.5,107.952z M346.5,182.952c12,0,22,10,22,22s-10,22-22,22s-22-10-22-22 S334.5,182.952,346.5,182.952z M264.9,132.252c12,0,22,10,22,22s-10,22-22,22s-22-10-22-22S252.9,132.252,264.9,132.252z M214.2,233.652c12,0,22,10,22,22s-10,22-22,22s-22-10-22-22S202.2,233.652,214.2,233.652z M152.5,174.052c12,0,22,10,22,22 s-10,22-22,22s-22-10-22-22C130.5,184.152,140.5,174.052,152.5,174.052z"></path> <path d="M718.5,331.452c-22.1-13.9-44.699-25.5-67.4-35.1c-51.1-21.5-102.6-32.1-149.9-32.1c-76.5,0-141.899,27.8-176.299,82.5 l-39.3,62.7l-12.4,19.8c-14,22.4-21.7,47.4-23.6,73.9c-1.8,24.4,1.4,50,9,75.8c22.4,76.2,83.6,154.601,172.6,210.5 c72.101,45.2,149.5,67.601,217.9,67.601c76,0,140.801-27.601,175-82.101c0.5-0.8,50.1-79.899,51.9-82.7 C941,588.552,870.6,426.852,718.5,331.452z M716.801,566.452c0,12-10,22-22,22s-22-10-22-22s10-22,22-22 S716.801,554.452,716.801,566.452z M688.1,405.552c12,0,22,10,22,22s-10,22-22,22s-22-10-22-22S676.1,405.552,688.1,405.552z M593.4,511.352c0,12-10,22-22,22c-8.301,0-15.701-4.8-19.5-11.8c-1.6-3.101-2.6-6.601-2.6-10.2c0-12,10-22,22-22 c5.699,0,10.898,2.2,14.799,5.899C590.6,499.251,593.4,504.952,593.4,511.352z M624.199,420.952c0,12-10,22-22,22s-22-10-22-22 s10-22,22-22S624.199,408.952,624.199,420.952z M518.4,341.652c9.1,0,17.1,5.8,20.4,13.8c1.1,2.601,1.699,5.3,1.699,8.3 c0,12-10,22-22,22c-7.5,0-14.1-3.899-18.1-9.699c-2.5-3.5-3.9-7.801-3.9-12.4C496.4,351.652,506.4,341.652,518.4,341.652z M789.1,721.751c-51.199,81.7-199.299,81.101-319.1,5.9c-60.5-38-107.1-90.7-131.7-144.1c-11.3-24.601-18-49.301-19.3-72.9 c-1.4-26.5,4-51.5,17.399-72.9c5.101-8.1,13-20.3,17.9-27.5c2.1-3.1,3.7-5.3,4.3-5.699c-0.3,1.8-0.6,3.6-0.8,5.5 c-3.2,28.399,7,62,27,96c12.8,21.899,29.7,43.899,49.6,65c25.2,26.6,55.401,51.5,88.5,72.3c102.699,64.399,230.5,86.6,288,45 C810.9,688.251,796.5,710.052,789.1,721.751z M807.199,528.952c0,12-10,22-22,22s-22-10-22-22s10-22,22-22 S807.199,516.952,807.199,528.952z"></path> </g> </g> </g></svg>';
                    break;
                case $basics[ 'button_close_svg' ] === 'svg-chat':
                    $svg_close = '<svg class="trig-svg-close" viewBox="0 0 24.00 24.00" fill="none" xmlns="http://www.w3.org/2000/svg" transform="matrix(1, 0, 0, 1, 0, 0)" stroke="' .esc_attr($svg_color) .'" stroke-width="0.24000000000000005"><g class="SVGRepo_bgCarrier" stroke-width="0" transform="translate(6.6,6.6), scale(0.45)"><rect x="0" y="0" width="24.00" height="24.00" rx="0" fill="' .esc_attr($svg_color) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <path fill-rule="evenodd" clip-rule="evenodd" d="M13.6288 20.4718L13.0867 21.3877C12.6035 22.204 11.3965 22.204 10.9133 21.3877L10.3712 20.4718C9.95073 19.7614 9.74049 19.4063 9.40279 19.2098C9.06509 19.0134 8.63992 19.0061 7.78958 18.9915C6.53422 18.9698 5.74689 18.8929 5.08658 18.6194C3.86144 18.1119 2.88807 17.1386 2.3806 15.9134C2 14.9946 2 13.8297 2 11.5V10.5C2 7.22657 2 5.58985 2.7368 4.38751C3.14908 3.71473 3.71473 3.14908 4.38751 2.7368C5.58985 2 7.22657 2 10.5 2H13.5C16.7734 2 18.4101 2 19.6125 2.7368C20.2853 3.14908 20.8509 3.71473 21.2632 4.38751C22 5.58985 22 7.22657 22 10.5V11.5C22 13.8297 22 14.9946 21.6194 15.9134C21.1119 17.1386 20.1386 18.1119 18.9134 18.6194C18.2531 18.8929 17.4658 18.9698 16.2104 18.9915C15.36 19.0061 14.9349 19.0134 14.5972 19.2098C14.2595 19.4062 14.0492 19.7614 13.6288 20.4718ZM8 11.75C7.58579 11.75 7.25 12.0858 7.25 12.5C7.25 12.9142 7.58579 13.25 8 13.25H13.5C13.9142 13.25 14.25 12.9142 14.25 12.5C14.25 12.0858 13.9142 11.75 13.5 11.75H8ZM7.25 9C7.25 8.58579 7.58579 8.25 8 8.25H16C16.4142 8.25 16.75 8.58579 16.75 9C16.75 9.41421 16.4142 9.75 16 9.75H8C7.58579 9.75 7.25 9.41421 7.25 9Z" fill="' .esc_attr($svg_bg) .'"></path> </g></svg>';
                    break;
                case $basics[ 'button_close_svg' ] === 'svg-chat-2':
                    $svg_close = '<svg class="trig-svg-close" viewBox="-7.2 -7.2 38.40 38.40" fill="' .esc_attr($svg_color) .'" xmlns="http://www.w3.org/2000/svg" transform="matrix(1, 0, 0, 1, 0, 0)"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-7.2" y="-7.2" width="38.40" height="38.40" rx="19.2" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <path d="M12 22C17.5228 22 22 17.5228 22 12C22 6.47715 17.5228 2 12 2C6.47715 2 2 6.47715 2 12C2 13.5997 2.37562 15.1116 3.04346 16.4525C3.22094 16.8088 3.28001 17.2161 3.17712 17.6006L2.58151 19.8267C2.32295 20.793 3.20701 21.677 4.17335 21.4185L6.39939 20.8229C6.78393 20.72 7.19121 20.7791 7.54753 20.9565C8.88837 21.6244 10.4003 22 12 22Z" stroke="' .esc_attr($svg_bg) .'" stroke-width="1.5"></path> <path opacity="0.5" d="M8 12H8.009M11.991 12H12M15.991 12H16" stroke="' .esc_attr($svg_bg) .'" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"></path> </g></svg>';
                    break;
                case $basics[ 'button_close_svg' ] === 'svg-chat-3':
                    $svg_close = '<svg class="trig-svg-close" viewBox="-7.2 -7.2 38.40 38.40" fill="' .esc_attr($svg_color) .'" xmlns="http://www.w3.org/2000/svg" transform="matrix(-1, 0, 0, 1, 0, 0)"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-7.2" y="-7.2" width="38.40" height="38.40" rx="19.2" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <path d="M12 22C17.5228 22 22 17.5228 22 12C22 6.47715 17.5228 2 12 2C6.47715 2 2 6.47715 2 12C2 13.5997 2.37562 15.1116 3.04346 16.4525C3.22094 16.8088 3.28001 17.2161 3.17712 17.6006L2.58151 19.8267C2.32295 20.793 3.20701 21.677 4.17335 21.4185L6.39939 20.8229C6.78393 20.72 7.19121 20.7791 7.54753 20.9565C8.88837 21.6244 10.4003 22 12 22Z" stroke="' .esc_attr($svg_bg) .'" stroke-width="1.5"></path> <path opacity="0.5" d="M8 12H8.009M11.991 12H12M15.991 12H16" stroke="' .esc_attr($svg_bg) .'" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"></path> </g></svg>';
                    break;
                case $basics[ 'button_close_svg' ] === 'svg-chat-4':
                    $svg_close = '<svg class="trig-svg-close" viewBox="0 0 24 24" fill="' .esc_attr($svg_bg) .'" xmlns="http://www.w3.org/2000/svg" transform="matrix(1, 0, 0, 1, 0, 0)"><g class="SVGRepo_bgCarrier" stroke-width="0"></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <path d="M12 22C17.5228 22 22 17.5228 22 12C22 6.47715 17.5228 2 12 2C6.47715 2 2 6.47715 2 12C2 13.5997 2.37562 15.1116 3.04346 16.4525C3.22094 16.8088 3.28001 17.2161 3.17712 17.6006L2.58151 19.8267C2.32295 20.793 3.20701 21.677 4.17335 21.4185L6.39939 20.8229C6.78393 20.72 7.19121 20.7791 7.54753 20.9565C8.88837 21.6244 10.4003 22 12 22Z" stroke="' .esc_attr($svg_color) .'" stroke-width="1.5"></path> <path opacity="0.5" d="M8 10.5H16" stroke="' .esc_attr($svg_color) .'" stroke-width="1.5" stroke-linecap="round"></path> <path opacity="0.5" d="M8 14H13.5" stroke="' .esc_attr($svg_color) .'" stroke-width="1.5" stroke-linecap="round"></path> </g></svg>';
                    break;
                case $basics[ 'button_close_svg' ] === 'svg-chat-5':
                    $svg_close = '<svg class="trig-svg-close" viewBox="0 0 24 24" fill="' .esc_attr($svg_bg) .'" xmlns="http://www.w3.org/2000/svg" transform="matrix(-1, 0, 0, 1, 0, 0)"><g class="SVGRepo_bgCarrier" stroke-width="0"></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <path d="M12 22C17.5228 22 22 17.5228 22 12C22 6.47715 17.5228 2 12 2C6.47715 2 2 6.47715 2 12C2 13.5997 2.37562 15.1116 3.04346 16.4525C3.22094 16.8088 3.28001 17.2161 3.17712 17.6006L2.58151 19.8267C2.32295 20.793 3.20701 21.677 4.17335 21.4185L6.39939 20.8229C6.78393 20.72 7.19121 20.7791 7.54753 20.9565C8.88837 21.6244 10.4003 22 12 22Z" stroke="' .esc_attr($svg_color) .'" stroke-width="1.5"></path> <path opacity="0.5" d="M8 10.5H16" stroke="' .esc_attr($svg_color) .'" stroke-width="1.5" stroke-linecap="round"></path> <path opacity="0.5" d="M8 14H13.5" stroke="' .esc_attr($svg_color) .'" stroke-width="1.5" stroke-linecap="round"></path> </g></svg>';
                    break;
                case $basics[ 'button_close_svg' ] === 'svg-chats':
                    $svg_close = '<svg class="trig-svg-close" viewBox="-8.4 -8.4 40.80 40.80" xmlns="http://www.w3.org/2000/svg" fill="none"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-8.4" y="-8.4" width="40.80" height="40.80" rx="20.4" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <path stroke="' .esc_attr($svg_color) .'" stroke-linejoin="round" stroke-width="2" d="M9.88235 15C13.261 15 16 12.5376 16 9.5C16 6.46243 13.261 4 9.88235 4C6.50367 4 3.76471 6.46243 3.76471 9.5C3.76471 10.3179 3.96327 11.094 4.31942 11.7917L3 15L6.82353 14.2642C7.72335 14.7322 8.76806 15 9.88235 15Z"></path> <path stroke="' .esc_attr($svg_color) .'" stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M10.8042 18.1242C11.759 18.6784 12.8966 19 14.1176 19C15.2319 19 16.2766 18.7322 17.1765 18.2642L21 19L19.6806 15.7917C20.0367 15.094 20.2353 14.3179 20.2353 13.5C20.2353 12.2553 19.7754 11.1071 19 10.1854C18.251 9.29505 17.2076 8.61598 16 8.26526"></path> <circle r="1" fill="' .esc_attr($svg_color) .'" transform="matrix(-1 0 0 1 13 9.5)"></circle> <circle r="1" fill="' .esc_attr($svg_color) .'" transform="matrix(-1 0 0 1 10 9.5)"></circle> <circle r="1" fill="' .esc_attr($svg_color) .'" transform="matrix(-1 0 0 1 7 9.5)"></circle> </g></svg>';
                    break;
                case $basics[ 'button_close_svg' ] === 'svg-chats-2':
                    $svg_close = '<svg class="trig-svg-close" viewBox="-7.2 -7.2 38.40 38.40" xmlns="http://www.w3.org/2000/svg" fill="none"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-7.2" y="-7.2" width="38.40" height="38.40" rx="19.2" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"><path stroke="' .esc_attr($svg_color) .'" stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M8 18.72C6.339 20.134 4.82 21 2 21c1-1 2.27-2.35 2.801-4.447C3.067 15.114 2 13.157 2 11c0-4.418 4.477-8 10-8 5.1 0 9.308 3.054 9.923 7"></path><path fill="' .esc_attr($svg_color) .'" stroke="' .esc_attr($svg_color) .'" stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M16 19.889c-3.314 0-6-1.99-6-4.445C10 12.99 12.686 11 16 11s6 1.99 6 4.444c0 1.199-.64 2.286-1.68 3.085.317 1.165 1.08 1.915 1.68 2.471-1.8 0-2.716-.544-3.792-1.422-.684.2-1.428.31-2.208.31z"></path></g></svg>';
                    break;
                case $basics[ 'button_close_svg' ] === 'svg-chats-3':
                    $svg_close = '<svg class="trig-svg-close" viewBox="-8.4 -8.4 40.80 40.80" xmlns="http://www.w3.org/2000/svg" fill="none"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-8.4" y="-8.4" width="40.80" height="40.80" rx="20.4" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"><path stroke="' .esc_attr($svg_color) .'" stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M13.584 7a5.001 5.001 0 1 0-8.809 4.675L4 14l2.325-.775c.214.136.44.256.675.359"></path><path fill="' .esc_attr($svg_color) .'" stroke="' .esc_attr($svg_color) .'" stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M15 20a5 5 0 1 1 4.225-2.325L20 20l-2.325-.775A4.976 4.976 0 0 1 15 20z"></path></g></svg>';
                    break;
                case $basics[ 'button_close_svg' ] === 'svg-elipsis-h':
                    $svg_close = '<svg class="trig-svg-close" viewBox="-0.48 -0.48 24.96 24.96" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" fill="' .esc_attr($svg_color) .'"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-0.48" y="-0.48" width="24.96" height="24.96" rx="12.48" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <title>elipsis-h</title> <desc>Created with sketchtool.</desc> <g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"> <g fill="' .esc_attr($svg_color) .'"> <path d="M18,14 C16.8954305,14 16,13.1045695 16,12 C16,10.8954305 16.8954305,10 18,10 C19.1045695,10 20,10.8954305 20,12 C20,13.1045695 19.1045695,14 18,14 Z M6,14 C4.8954305,14 4,13.1045695 4,12 C4,10.8954305 4.8954305,10 6,10 C7.1045695,10 8,10.8954305 8,12 C8,13.1045695 7.1045695,14 6,14 Z M12,14 C10.8954305,14 10,13.1045695 10,12 C10,10.8954305 10.8954305,10 12,10 C13.1045695,10 14,10.8954305 14,12 C14,13.1045695 13.1045695,14 12,14 Z"> </path> </g> </g> </g></svg>';
                    break;
                case $basics[ 'button_close_svg' ] === 'svg-elipsis-v':
                    $svg_close = '<svg class="trig-svg-close" viewBox="-7.2 -7.2 38.40 38.40" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" fill="' .esc_attr($svg_bg) .'"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-7.2" y="-7.2" width="38.40" height="38.40" rx="19.2" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <title>elipsis-v</title> <desc>Created with sketchtool.</desc> <g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"> <g fill="' .esc_attr($svg_color) .'"> <path d="M12,20 C10.8954305,20 10,19.1045695 10,18 C10,16.8954305 10.8954305,16 12,16 C13.1045695,16 14,16.8954305 14,18 C14,19.1045695 13.1045695,20 12,20 Z M12,14 C10.8954305,14 10,13.1045695 10,12 C10,10.8954305 10.8954305,10 12,10 C13.1045695,10 14,10.8954305 14,12 C14,13.1045695 13.1045695,14 12,14 Z M12,8 C10.8954305,8 10,7.1045695 10,6 C10,4.8954305 10.8954305,4 12,4 C13.1045695,4 14,4.8954305 14,6 C14,7.1045695 13.1045695,8 12,8 Z"> </path> </g> </g> </g></svg>';
                    break;
                case $basics[ 'button_close_svg' ] === 'svg-home':
                    $svg_close = '<svg class="trig-svg-close" fill="' .esc_attr($svg_color) .'" viewBox="-9.6 -9.6 43.20 43.20" xmlns="http://www.w3.org/2000/svg" stroke="' .esc_attr($svg_color) .'"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-9.6" y="-9.6" width="43.20" height="43.20" rx="21.6" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"><path d="M3.012,10.981,3,11H5v9a1,1,0,0,0,1,1H18a1,1,0,0,0,1-1V11h2a1,1,0,0,0,.555-1.832l-9-6a1,1,0,0,0-1.11,0l-9,6a1,1,0,0,0-.277,1.387A.98.98,0,0,0,3.012,10.981ZM10,14a1,1,0,0,1,1-1h2a1,1,0,0,1,1,1v5H10Z"></path></g></svg>';
                    break;
                case $basics[ 'button_close_svg' ] === 'svg-home-2':
                    $svg_close = '<svg class="trig-svg-close"  fill="' .esc_attr($svg_color) .'" viewBox="-7.2 -7.2 38.40 38.40" xmlns="http://www.w3.org/2000/svg" stroke="' .esc_attr($svg_color) .'"><g id="SVGRepo_bgCarrier" stroke-width="0"><rect x="-7.2" y="-7.2" width="38.40" height="38.40" rx="0" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g id="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g id="SVGRepo_iconCarrier"><path d="M3.012,10.981,3,11H5v9a1,1,0,0,0,1,1H18a1,1,0,0,0,1-1V11h2a1,1,0,0,0,.555-1.832l-9-6a1,1,0,0,0-1.11,0l-9,6a1,1,0,0,0-.277,1.387A.98.98,0,0,0,3.012,10.981ZM10,14a1,1,0,0,1,1-1h2a1,1,0,0,1,1,1v5H10Z"></path></g></svg>';
                    break;
                case $basics[ 'button_close_svg' ] === 'svg-info':
                    $svg_close = '<svg class="trig-svg-close" fill="' .esc_attr($svg_color) .'" viewBox="-9.6 -9.6 51.20 51.20" version="1.1" xmlns="http://www.w3.org/2000/svg" stroke="' .esc_attr($svg_color) .'"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-9.6" y="-9.6" width="51.20" height="51.20" rx="25.6" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <title>info</title> <path d="M16.247 4.733c0 1.684 1.271 2.825 2.84 2.825s2.842-1.142 2.842-2.825c0-1.685-1.272-2.826-2.842-2.826-1.568 0-2.84 1.141-2.84 2.826zM10.096 14.375c0 0.334-0.061 1.163 0.008 1.662l2.479-2.983c0.513-0.562 1.106-0.955 1.409-0.849s0.47 0.463 0.371 0.795l-4.103 13.59c-0.473 1.588 0.421 3.148 2.599 3.504 3.189 0 5.084-2.158 6.948-4.955 0-0.334 0.111-1.213 0.044-1.713l-2.479 2.982c-0.514 0.562-1.151 0.955-1.455 0.85-0.28-0.098-0.444-0.41-0.389-0.721l4.132-13.653c0.344-1.734-0.59-3.312-2.564-3.514-2.076 0.001-5.136 2.209-7 5.005z"></path> </g></svg>';
                    break;
                case $basics[ 'button_close_svg' ] === 'svg-location':
                    $svg_close = '<svg class="trig-svg-close" viewBox="-7.2 -7.2 38.40 38.40" fill="none" xmlns="http://www.w3.org/2000/svg"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-7.2" y="-7.2" width="38.40" height="38.40" rx="19.2" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <path d="M21.3046 4.69335C21.908 3.41959 20.5806 2.09225 19.3069 2.69561L2.83473 10.4982C1.56185 11.1011 1.74664 12.9674 3.11305 13.309L9.17556 14.8247L10.6912 20.8872C11.0328 22.2536 12.8991 22.4384 13.502 21.1655L21.3046 4.69335Z" fill="' .esc_attr($svg_color) .'"></path> </g></svg>';
                    break;
                case $basics[ 'button_close_svg' ] === 'svg-location-2':
                    $svg_close = '<svg class="trig-svg-close" viewBox="-7.2 -7.2 38.40 38.40" fill="none" xmlns="http://www.w3.org/2000/svg"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-7.2" y="-7.2" width="38.40" height="38.40" rx="19.2" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <g><g> <path fill-rule="evenodd" clip-rule="evenodd" d="M8.89129 21.0787L8.9461 21.1315L8.95039 21.1357C9.95462 22.098 10.9283 22.7576 12.0296 22.7449C13.1259 22.7323 14.0956 22.0555 15.0992 21.0783C16.4747 19.7455 18.2545 17.9477 19.5403 15.8149C20.831 13.6741 21.6639 11.1292 21.0372 8.33595C18.9197 -1.10413 5.09133 -1.11519 2.96276 8.32592C2.35382 11.04 3.12314 13.5227 4.34999 15.6268C5.57222 17.7231 7.2824 19.5029 8.65394 20.8471C8.73386 20.9254 8.81273 21.0023 8.89035 21.0778L8.89129 21.0787ZM12 6.25012C10.2051 6.25012 8.75 7.7052 8.75 9.50012C8.75 11.295 10.2051 12.7501 12 12.7501C13.7949 12.7501 15.25 11.295 15.25 9.50012C15.25 7.7052 13.7949 6.25012 12 6.25012Z" fill="' .esc_attr($svg_color) .'"></path> </g> </g> </g></svg>';
                    break;
                case $basics[ 'button_close_svg' ] === 'svg-mail':
                    $svg_close = '<svg class="trig-svg-close" viewBox="-7.2 -7.2 38.40 38.40" fill="none" xmlns="http://www.w3.org/2000/svg"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-7.2" y="-7.2" width="38.40" height="38.40" rx="19.2" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <path opacity="0.15" d="M21 18V6.00001C21 5.72387 20.8881 5.47387 20.7071 5.29291L20.5 5.50001L13.4142 12.5858C12.6332 13.3668 11.3668 13.3668 10.5858 12.5858L3.5 5.50001L3.29289 5.29291C3.11193 5.47387 3 5.72387 3 6.00001V18C3 18.5523 3.44772 19 4 19H20C20.5523 19 21 18.5523 21 18Z" fill="' .esc_attr($svg_color) .'"></path> <path d="M3.29289 5.29289C3.47386 5.11193 3.72386 5 4 5H20C20.2761 5 20.5261 5.11193 20.7071 5.29289M3.29289 5.29289C3.11193 5.47386 3 5.72386 3 6V18C3 18.5523 3.44772 19 4 19H20C20.5523 19 21 18.5523 21 18V6C21 5.72386 20.8881 5.47386 20.7071 5.29289M3.29289 5.29289L10.5858 12.5858C11.3668 13.3668 12.6332 13.3668 13.4142 12.5858L20.7071 5.29289" stroke="' .esc_attr($svg_color) .'" stroke-width="1.5" stroke-linecap="round" stroke-linejoin="round"></path> </g></svg>';
                    break;
                case $basics[ 'button_close_svg' ] === 'svg-pin':
                    $svg_close = '<svg class="trig-svg-close" viewBox="-9.6 -9.6 43.20 43.20" fill="none" xmlns="http://www.w3.org/2000/svg"><g class="SVGRepo_bgCarrier" stroke-width="0" transform="translate(0,0), scale(1)"><rect x="-9.6" y="-9.6" width="43.20" height="43.20" rx="21.6" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <path d="M19.1835 7.80516L16.2188 4.83755C14.1921 2.8089 13.1788 1.79457 12.0904 2.03468C11.0021 2.2748 10.5086 3.62155 9.5217 6.31506L8.85373 8.1381C8.59063 8.85617 8.45908 9.2152 8.22239 9.49292C8.11619 9.61754 7.99536 9.72887 7.86251 9.82451C7.56644 10.0377 7.19811 10.1392 6.46145 10.3423C4.80107 10.8 3.97088 11.0289 3.65804 11.5721C3.5228 11.8069 3.45242 12.0735 3.45413 12.3446C3.45809 12.9715 4.06698 13.581 5.28476 14.8L6.69935 16.2163L2.22345 20.6964C1.92552 20.9946 1.92552 21.4782 2.22345 21.7764C2.52138 22.0746 3.00443 22.0746 3.30236 21.7764L7.77841 17.2961L9.24441 18.7635C10.4699 19.9902 11.0827 20.6036 11.7134 20.6045C11.9792 20.6049 12.2404 20.5358 12.4713 20.4041C13.0192 20.0914 13.2493 19.2551 13.7095 17.5825C13.9119 16.8472 14.013 16.4795 14.2254 16.1835C14.3184 16.054 14.4262 15.9358 14.5468 15.8314C14.8221 15.593 15.1788 15.459 15.8922 15.191L17.7362 14.4981C20.4 13.4973 21.7319 12.9969 21.9667 11.9115C22.2014 10.826 21.1954 9.81905 19.1835 7.80516Z" fill="' .esc_attr($svg_color) .'"></path> </g></svg>';
                    break;
                case $basics[ 'button_close_svg' ] === 'svg-play':
                    $svg_close = '<svg class="trig-svg-close" viewBox="-10.8 -10.8 45.60 45.60" fill="none" xmlns="http://www.w3.org/2000/svg"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-10.8" y="-10.8" width="45.60" height="45.60" rx="22.8" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <path d="M21.4086 9.35258C23.5305 10.5065 23.5305 13.4935 21.4086 14.6474L8.59662 21.6145C6.53435 22.736 4 21.2763 4 18.9671L4 5.0329C4 2.72368 6.53435 1.26402 8.59661 2.38548L21.4086 9.35258Z" fill="' .esc_attr($svg_color) .'"></path> </g></svg>';
                    break;
                case $basics[ 'button_close_svg' ] === 'svg-settings':
                    $svg_close = '<svg class="trig-svg-close" viewBox="-7.2 -7.2 38.40 38.40" fill="none" xmlns="http://www.w3.org/2000/svg"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-7.2" y="-7.2" width="38.40" height="38.40" rx="19.2" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <path d="M12 14.93C11.4205 14.93 10.854 14.7582 10.3722 14.4362C9.89035 14.1143 9.51481 13.6567 9.29304 13.1213C9.07128 12.5859 9.01325 11.9968 9.12631 11.4284C9.23936 10.86 9.51842 10.338 9.92819 9.92819C10.338 9.51842 10.86 9.23936 11.4284 9.12631C11.9968 9.01325 12.5859 9.07128 13.1213 9.29304C13.6567 9.51481 14.1143 9.89035 14.4362 10.3722C14.7582 10.854 14.93 11.4205 14.93 12C14.93 12.7771 14.6213 13.5224 14.0718 14.0718C13.5224 14.6213 12.7771 14.93 12 14.93ZM12 10.57C11.7172 10.57 11.4407 10.6539 11.2055 10.811C10.9704 10.9681 10.7871 11.1915 10.6789 11.4528C10.5706 11.7141 10.5423 12.0016 10.5975 12.279C10.6527 12.5564 10.7889 12.8112 10.9888 13.0112C11.1888 13.2112 11.4436 13.3474 11.721 13.4025C11.9984 13.4577 12.2859 13.4294 12.5472 13.3212C12.8085 13.2129 13.0319 13.0296 13.189 12.7945C13.3461 12.5593 13.43 12.2828 13.43 12C13.43 11.6207 13.2793 11.257 13.0112 10.9888C12.743 10.7207 12.3793 10.57 12 10.57Z" fill="' .esc_attr($svg_color) .'"></path> <path d="M12.06 20.75C11.7676 20.7487 11.4784 20.6896 11.2089 20.5762C10.9394 20.4628 10.6949 20.2973 10.4896 20.0892C10.2842 19.881 10.122 19.6344 10.0123 19.3634C9.90252 19.0924 9.84737 18.8024 9.85001 18.51C9.84606 18.4198 9.81676 18.3326 9.76546 18.2583C9.71416 18.184 9.64295 18.1257 9.56001 18.09C9.46824 18.0479 9.36604 18.034 9.26634 18.05C9.16665 18.066 9.07396 18.1112 9.00001 18.18C8.58482 18.592 8.02493 18.8253 7.44001 18.83C6.8514 18.8338 6.28454 18.6077 5.86001 18.2C5.6538 17.9938 5.49022 17.7491 5.37861 17.4797C5.26701 17.2103 5.20956 16.9216 5.20956 16.63C5.20956 16.3384 5.26701 16.0497 5.37861 15.7803C5.49022 15.5109 5.6538 15.2662 5.86001 15.06C5.93053 14.9957 5.98119 14.9126 6.006 14.8205C6.0308 14.7283 6.02873 14.631 6.00001 14.54C5.95128 14.4556 5.88137 14.3854 5.79719 14.3363C5.71301 14.2872 5.61747 14.2609 5.52001 14.26C4.93163 14.2577 4.36714 14.027 3.94554 13.6166C3.52393 13.2062 3.27815 12.6481 3.26001 12.06C3.26132 11.7685 3.32004 11.48 3.43282 11.2112C3.5456 10.9424 3.71022 10.6984 3.9173 10.4931C4.12437 10.2879 4.36984 10.1255 4.63969 10.0152C4.90953 9.9048 5.19847 9.84868 5.49001 9.85C5.5802 9.84605 5.66746 9.81675 5.74175 9.76545C5.81604 9.71415 5.87436 9.64294 5.91001 9.56C5.95213 9.46823 5.96606 9.36603 5.95004 9.26633C5.93402 9.16664 5.88876 9.07395 5.82001 9C5.40797 8.58481 5.17468 8.02492 5.17001 7.44C5.1649 7.14801 5.21797 6.85792 5.32613 6.58665C5.4343 6.31538 5.59539 6.06836 5.80001 5.86C6.00616 5.65379 6.25092 5.49021 6.52031 5.3786C6.78969 5.267 7.07842 5.20955 7.37001 5.20955C7.6616 5.20955 7.95033 5.267 8.21971 5.3786C8.4891 5.49021 8.73385 5.65379 8.94001 5.86C9.01201 5.9285 9.10041 5.97735 9.19672 6.00187C9.29303 6.02638 9.39402 6.02574 9.49001 6C9.57752 5.95207 9.65169 5.88308 9.70582 5.79927C9.75995 5.71546 9.79232 5.61947 9.80001 5.52C9.79973 4.92989 10.0293 4.36287 10.4399 3.93912C10.8506 3.51537 11.4102 3.2682 12 3.25C12.2915 3.25261 12.5797 3.31263 12.8481 3.42662C13.1164 3.5406 13.3597 3.70633 13.564 3.91434C13.7682 4.12234 13.9296 4.36855 14.0387 4.63891C14.1478 4.90926 14.2026 5.19846 14.2 5.49C14.2038 5.5815 14.2317 5.67038 14.2809 5.74764C14.33 5.8249 14.3987 5.88781 14.48 5.93C14.5683 5.96241 14.6639 5.96927 14.7558 5.94982C14.8478 5.93036 14.9324 5.88537 15 5.82C15.4152 5.40796 15.9751 5.17467 16.56 5.17C16.8525 5.16083 17.1438 5.21204 17.4156 5.32044C17.6875 5.42883 17.9341 5.59208 18.14 5.8C18.3462 6.00615 18.5098 6.25091 18.6214 6.5203C18.733 6.78968 18.7905 7.07841 18.7905 7.37C18.7905 7.66159 18.733 7.95032 18.6214 8.2197C18.5098 8.48909 18.3462 8.73385 18.14 8.94C18.0767 9.01489 18.0333 9.10463 18.0141 9.20082C17.9949 9.29701 18.0003 9.3965 18.03 9.49C18.0779 9.57751 18.1469 9.65168 18.2307 9.70581C18.3145 9.75994 18.4105 9.79231 18.51 9.8C19.0949 9.80745 19.6544 10.0404 20.0717 10.4503C20.489 10.8602 20.732 11.4153 20.75 12C20.7474 12.2915 20.6874 12.5797 20.5734 12.848C20.4594 13.1164 20.2937 13.3597 20.0857 13.5639C19.8777 13.7682 19.6315 13.9296 19.3611 14.0387C19.0907 14.1478 18.8015 14.2026 18.51 14.2C18.4185 14.2038 18.3296 14.2317 18.2524 14.2809C18.1751 14.33 18.1122 14.3987 18.07 14.48C18.0376 14.5683 18.0307 14.6638 18.0502 14.7558C18.0696 14.8478 18.1146 14.9324 18.18 15C18.5921 15.4152 18.8253 15.9751 18.83 16.56C18.8351 16.852 18.782 17.1421 18.6739 17.4133C18.5657 17.6846 18.4046 17.9316 18.2 18.14C17.9939 18.3462 17.7491 18.5098 17.4797 18.6214C17.2103 18.733 16.9216 18.7904 16.63 18.7904C16.3384 18.7904 16.0497 18.733 15.7803 18.6214C15.5109 18.5098 15.2662 18.3462 15.06 18.14C14.9924 18.0746 14.9078 18.0296 14.8158 18.0102C14.7239 17.9907 14.6283 17.9976 14.54 18.03C14.4556 18.0787 14.3854 18.1486 14.3363 18.2328C14.2872 18.317 14.2609 18.4125 14.26 18.51C14.2526 19.0949 14.0196 19.6544 13.6097 20.0717C13.1998 20.489 12.6447 20.732 12.06 20.75ZM9.35001 16.54C9.61524 16.5369 9.87797 16.5915 10.12 16.7C10.4772 16.8489 10.7835 17.0982 11.0018 17.4177C11.2202 17.7372 11.3411 18.1131 11.35 18.5C11.3472 18.6929 11.4199 18.8792 11.5525 19.0193C11.6852 19.1594 11.8673 19.2422 12.06 19.25C12.2527 19.2348 12.4324 19.1466 12.5625 19.0036C12.6925 18.8605 12.7632 18.6733 12.76 18.48C12.7624 18.0918 12.8744 17.7121 13.0832 17.3848C13.292 17.0575 13.589 16.7958 13.94 16.63C14.3052 16.4781 14.7072 16.4379 15.0952 16.5144C15.4832 16.5909 15.8399 16.7808 16.12 17.06C16.2526 17.1926 16.4325 17.2671 16.62 17.2671C16.8075 17.2671 16.9874 17.1926 17.12 17.06C17.2526 16.9274 17.3271 16.7475 17.3271 16.56C17.3271 16.3725 17.2526 16.1926 17.12 16.06C16.8425 15.7788 16.6545 15.4216 16.5798 15.0336C16.505 14.6456 16.5469 14.2442 16.7 13.88C16.8577 13.5291 17.1133 13.2311 17.4362 13.0218C17.759 12.8126 18.1353 12.7008 18.52 12.7C18.7103 12.7028 18.8941 12.6311 19.0323 12.5004C19.1705 12.3696 19.2522 12.1901 19.26 12C19.2472 11.8064 19.1597 11.6253 19.0162 11.4947C18.8726 11.3642 18.684 11.2944 18.49 11.3C18.0986 11.2894 17.7179 11.1695 17.391 10.9539C17.0641 10.7383 16.804 10.4356 16.64 10.08C16.4903 9.71114 16.4513 9.30669 16.5277 8.91602C16.604 8.52535 16.7925 8.16536 17.07 7.88C17.1357 7.81434 17.1878 7.73639 17.2233 7.6506C17.2588 7.56481 17.2771 7.47286 17.2771 7.38C17.2771 7.28714 17.2588 7.19519 17.2233 7.1094C17.1878 7.02361 17.1357 6.94566 17.07 6.88C17.0043 6.81434 16.9264 6.76225 16.8406 6.72672C16.7548 6.69118 16.6629 6.67289 16.57 6.67289C16.4772 6.67289 16.3852 6.69118 16.2994 6.72672C16.2136 6.76225 16.1357 6.81434 16.07 6.88C15.7889 7.14113 15.4385 7.31587 15.0608 7.38337C14.6831 7.45088 14.2939 7.4083 13.9397 7.26072C13.5855 7.11314 13.2812 6.86679 13.0632 6.55105C12.8452 6.2353 12.7226 5.86351 12.71 5.48C12.7128 5.28976 12.6412 5.10595 12.5104 4.96773C12.3797 4.82951 12.2001 4.7478 12.01 4.74C11.8164 4.75286 11.6353 4.84026 11.5047 4.98385C11.3742 5.12744 11.3044 5.31603 11.31 5.51C11.2994 5.90145 11.1795 6.28212 10.9639 6.60903C10.7483 6.93593 10.4456 7.19605 10.09 7.36C9.72115 7.50966 9.3167 7.54869 8.92603 7.47233C8.53536 7.39598 8.17537 7.20753 7.89001 6.93C7.82435 6.86434 7.7464 6.81225 7.66061 6.77672C7.57482 6.74118 7.48287 6.72289 7.39001 6.72289C7.29715 6.72289 7.2052 6.74118 7.11941 6.77672C7.03362 6.81225 6.95567 6.86434 6.89001 6.93C6.82435 6.99566 6.77226 7.07361 6.73673 7.1594C6.70119 7.24519 6.6829 7.33714 6.6829 7.43C6.6829 7.52286 6.70119 7.61481 6.73673 7.7006C6.77226 7.78639 6.82435 7.86434 6.89001 7.93C7.16585 8.21235 7.35197 8.57002 7.42493 8.95795C7.49789 9.34588 7.45443 9.74673 7.30001 10.11C7.15113 10.4672 6.90183 10.7735 6.58234 10.9918C6.26284 11.2101 5.88687 11.3311 5.50001 11.34C5.30712 11.3372 5.12077 11.4099 4.98067 11.5425C4.84058 11.6752 4.75781 11.8572 4.75001 12.05C4.76525 12.2427 4.85336 12.4224 4.99641 12.5525C5.13947 12.6825 5.3267 12.7531 5.52001 12.75C5.90823 12.7524 6.28788 12.8644 6.6152 13.0732C6.94251 13.282 7.20417 13.579 7.37001 13.93C7.52192 14.2952 7.56215 14.6972 7.48561 15.0852C7.40907 15.4732 7.2192 15.8299 6.94001 16.11C6.87435 16.1757 6.82226 16.2536 6.78673 16.3394C6.75119 16.4252 6.7329 16.5171 6.7329 16.61C6.7329 16.7029 6.75119 16.7948 6.78673 16.8806C6.82226 16.9664 6.87435 17.0443 6.94001 17.11C7.00567 17.1757 7.08362 17.2277 7.16941 17.2633C7.2552 17.2988 7.34715 17.3171 7.44001 17.3171C7.53287 17.3171 7.62482 17.2988 7.71061 17.2633C7.7964 17.2277 7.87435 17.1757 7.94001 17.11C8.3201 16.7471 8.82451 16.5432 9.35001 16.54Z" fill="' .esc_attr($svg_color) .'"></path> </g></svg>';
                    break;
                case $basics[ 'button_close_svg' ] === 'svg-share':
                    $svg_close = '<svg class="trig-svg-close" viewBox="-8.4 -8.4 40.80 40.80" fill="none" xmlns="http://www.w3.org/2000/svg"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-8.4" y="-8.4" width="40.80" height="40.80" rx="20.4" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <path d="M9 11.5C9 12.8807 7.88071 14 6.5 14C5.11929 14 4 12.8807 4 11.5C4 10.1193 5.11929 9 6.5 9C7.88071 9 9 10.1193 9 11.5Z" stroke="' .esc_attr($svg_color) .'" stroke-width="1.5"></path> <path opacity="0.5" d="M14.3206 16.8017L9 13.29" stroke="' .esc_attr($svg_color) .'" stroke-width="1.5" stroke-linecap="round"></path> <path opacity="0.5" d="M14.4207 6.83984L9.1001 10.3515" stroke="' .esc_attr($svg_color) .'" stroke-width="1.5" stroke-linecap="round"></path> <path d="M19 18.5C19 19.8807 17.8807 21 16.5 21C15.1193 21 14 19.8807 14 18.5C14 17.1193 15.1193 16 16.5 16C17.8807 16 19 17.1193 19 18.5Z" stroke="' .esc_attr($svg_color) .'" stroke-width="1.5"></path> <path d="M19 5.5C19 6.88071 17.8807 8 16.5 8C15.1193 8 14 6.88071 14 5.5C14 4.11929 15.1193 3 16.5 3C17.8807 3 19 4.11929 19 5.5Z" stroke="' .esc_attr($svg_color) .'" stroke-width="1.5"></path> </g></svg>';
                    break;
                case $basics[ 'button_close_svg' ] === 'svg-share-2':
                    $svg_close = '<svg class="trig-svg-close" viewBox="-8.4 -8.4 40.80 40.80" fill="none" xmlns="http://www.w3.org/2000/svg"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="-8.4" y="-8.4" width="40.80" height="40.80" rx="20.4" fill="' .esc_attr($svg_bg) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <g opacity="0.5"> <path d="M7.20468 7.56232C7.51523 7.28822 7.54478 6.81427 7.27069 6.50371C6.99659 6.19316 6.52264 6.1636 6.21208 6.4377C4.39676 8.03992 3.25 10.3865 3.25 13C3.25 13.4142 3.58579 13.75 4 13.75C4.41421 13.75 4.75 13.4142 4.75 13C4.75 10.8347 5.69828 8.89188 7.20468 7.56232Z" fill="' .esc_attr($svg_color) .'"></path> <path d="M17.7879 6.4377C17.4774 6.1636 17.0034 6.19316 16.7293 6.50371C16.4552 6.81427 16.4848 7.28822 16.7953 7.56232C18.3017 8.89188 19.25 10.8347 19.25 13C19.25 13.4142 19.5858 13.75 20 13.75C20.4142 13.75 20.75 13.4142 20.75 13C20.75 10.3865 19.6032 8.03992 17.7879 6.4377Z" fill="' .esc_attr($svg_color) .'"></path> <path d="M10.1869 20.0217C9.7858 19.9184 9.37692 20.1599 9.27367 20.5611C9.17043 20.9622 9.41192 21.3711 9.81306 21.4743C10.5129 21.6544 11.2458 21.75 12 21.75C12.7542 21.75 13.4871 21.6544 14.1869 21.4743C14.5881 21.3711 14.8296 20.9622 14.7263 20.5611C14.6231 20.1599 14.2142 19.9184 13.8131 20.0217C13.2344 20.1706 12.627 20.25 12 20.25C11.373 20.25 10.7656 20.1706 10.1869 20.0217Z" fill="' .esc_attr($svg_color) .'"></path> </g> <path d="M9 6C9 7.65685 10.3431 9 12 9C13.6569 9 15 7.65685 15 6C15 4.34315 13.6569 3 12 3C10.3431 3 9 4.34315 9 6Z" fill="' .esc_attr($svg_color) .'"></path> <path d="M2.5 18C2.5 19.6569 3.84315 21 5.5 21C7.15685 21 8.5 19.6569 8.5 18C8.5 16.3431 7.15685 15 5.5 15C3.84315 15 2.5 16.3431 2.5 18Z" fill="' .esc_attr($svg_color) .'"></path> <path d="M18.5 21C16.8431 21 15.5 19.6569 15.5 18C15.5 16.3431 16.8431 15 18.5 15C20.1569 15 21.5 16.3431 21.5 18C21.5 19.6569 20.1569 21 18.5 21Z" fill="' .esc_attr($svg_color) .'"></path> </g></svg>';
                    break;
                case $basics[ 'button_close_svg' ] === 'svg-minus':
                    $svg_close = '<svg class="trig-svg-close" viewBox="0 0 32.00 32.00" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" xmlns:sketch="http://www.bohemiancoding.com/sketch/ns" fill="' .esc_attr($svg_bg) .'"><g class="SVGRepo_bgCarrier" stroke-width="0" transform="translate(6.4,6.4), scale(0.6)"><rect x="0" y="0" width="32.00" height="32.00" rx="0" fill="' .esc_attr($svg_color) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <title>minus-square</title> <desc>Created with Sketch Beta.</desc> <defs> </defs> <g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd" sketch:type="MSPage"> <g sketch:type="MSLayerGroup" transform="translate(-154.000000, -1037.000000)" fill="' .esc_attr($svg_bg) .'"> <path d="M176,1054 L164,1054 C163.448,1054 163,1053.55 163,1053 C163,1052.45 163.448,1052 164,1052 L176,1052 C176.552,1052 177,1052.45 177,1053 C177,1053.55 176.552,1054 176,1054 L176,1054 Z M182,1037 L158,1037 C155.791,1037 154,1038.79 154,1041 L154,1065 C154,1067.21 155.791,1069 158,1069 L182,1069 C184.209,1069 186,1067.21 186,1065 L186,1041 C186,1038.79 184.209,1037 182,1037 L182,1037 Z" sketch:type="MSShapeGroup"> </path> </g> </g> </g></svg>';
                    break;
                case $basics[ 'button_close_svg' ] === 'svg-minus-2':
                    $svg_close = '<svg class="trig-svg-close" viewBox="0 0 32.00 32.00" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" xmlns:sketch="http://www.bohemiancoding.com/sketch/ns" fill="' .esc_attr($svg_bg) .'"><g class="SVGRepo_bgCarrier" stroke-width="0" transform="translate(6.4,6.4), scale(0.6)"><rect x="0" y="0" width="32.00" height="32.00" rx="16" fill="' .esc_attr($svg_color) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <title>minus-circle</title> <desc>Created with Sketch Beta.</desc> <defs> </defs> <g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd" sketch:type="MSPage"> <g sketch:type="MSLayerGroup" transform="translate(-518.000000, -1089.000000)" fill="' .esc_attr($svg_bg) .'"> <path d="M540,1106 L528,1106 C527.447,1106 527,1105.55 527,1105 C527,1104.45 527.447,1104 528,1104 L540,1104 C540.553,1104 541,1104.45 541,1105 C541,1105.55 540.553,1106 540,1106 L540,1106 Z M534,1089 C525.163,1089 518,1096.16 518,1105 C518,1113.84 525.163,1121 534,1121 C542.837,1121 550,1113.84 550,1105 C550,1096.16 542.837,1089 534,1089 L534,1089 Z" sketch:type="MSShapeGroup"> </path> </g> </g> </g></svg>';
                    break;
                case $basics[ 'button_close_svg' ] === 'svg-x':
                    $svg_close = '<svg class="trig-svg-close" viewBox="0 0 20.00 20.00" xmlns="http://www.w3.org/2000/svg" fill="' .esc_attr($svg_bg) .'"><g class="SVGRepo_bgCarrier" stroke-width="0" transform="translate(4,4), scale(0.6)"><rect x="0" y="0" width="20.00" height="20.00" rx="0" fill="' .esc_attr($svg_color) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <path fill="' .esc_attr($svg_bg) .'" d="M18.1818182,0 C19.1859723,0 20,0.814027728 20,1.81818182 L20,18.1818182 C20,19.1859723 19.1859723,20 18.1818182,20 L1.81818182,20 C0.814027728,20 0,19.1859723 0,18.1818182 L0,1.81818182 C0,0.814027728 0.814027728,0 1.81818182,0 L18.1818182,0 Z M12.2066229,6.81750327 L10.01,9.011 L7.81496625,6.81750327 C7.57521591,6.57797386 7.20156116,6.5541821 6.93520889,6.74601683 L6.85072984,6.81794775 C6.58458604,7.08433702 6.58478504,7.51604037 6.85117431,7.78218417 L6.85117431,7.78218417 L9.046,9.975 L6.85117431,12.1680169 C6.58478504,12.4341607 6.58458604,12.865864 6.85072984,13.1322533 C7.11687363,13.3986426 7.54857698,13.3988416 7.81496625,13.1326978 L10.01,10.938 L12.2066229,13.1326978 C12.4463733,13.3722272 12.820028,13.3960189 13.0863803,13.2041842 L13.1708593,13.1322533 C13.4370031,12.865864 13.4368041,12.4341607 13.1704149,12.1680169 L13.1704149,12.1680169 L10.975,9.975 L13.1704149,7.78218417 C13.4368041,7.51604037 13.4370031,7.08433702 13.1708593,6.81794775 C12.9047155,6.55155848 12.4730122,6.55135948 12.2066229,6.81750327 Z"></path> </g></svg>';
                    break;
                case $basics[ 'button_close_svg' ] === 'svg-x-2':
                    $svg_close = '<svg class="trig-svg-close" viewBox="0 0 32.00 32.00" xmlns="http://www.w3.org/2000/svg" fill="' .esc_attr($svg_bg) .'"><g class="SVGRepo_bgCarrier" stroke-width="0"><rect x="0" y="0" width="32.00" height="32.00" rx="16" fill="' .esc_attr($svg_color) .'" strokewidth="0"></rect></g><g class="SVGRepo_tracerCarrier" stroke-linecap="round" stroke-linejoin="round"></g><g class="SVGRepo_iconCarrier"> <g fill="none" fill-rule="evenodd"> <path d="m0 0h32v32h-32z"></path> <path d="m16 0c8.836556 0 16 7.163444 16 16s-7.163444 16-16 16-16-7.163444-16-16 7.163444-16 16-16zm-2.8284271 11.7573593c-.3905243-.3905243-1.0236893-.3905243-1.4142136 0s-.3905243 1.0236893 0 1.4142136l2.8284271 2.8284271-2.8284271 2.8284271c-.3905243.3905243-.3905243 1.0236893 0 1.4142136s1.0236893.3905243 1.4142136 0l2.8284271-2.8284271 2.8284271 2.8284271c.3905243.3905243 1.0236893.3905243 1.4142136 0s.3905243-1.0236893 0-1.4142136l-2.8284271-2.8284271 2.8284271-2.8284271c.3905243-.3905243.3905243-1.0236893 0-1.4142136s-1.0236893-.3905243-1.4142136 0l-2.8284271 2.8284271z" fill="' .esc_attr($svg_bg) .'"></path> </g> </g></svg>';
                    break;
                }
            }

            $_safe_trig_svg_open            = ! empty($open_svg_class) ? $svg_open : '';
            $_safe_trig_svg_close           = ! empty($close_svg_class) && empty($the_same_svg) ? $svg_close : '';

            // img
            // compare two images (if returns 0, the strings are the same)
            $open_close_img_the_same        = $panel_type === 'toggler' &&  ! empty($basics[ 'button_open_img' ]['url']) && ! empty($basics[ 'button_close_img' ]['url']) ? strcmp($basics[ 'button_open_img' ]['url'], $basics[ 'button_close_img' ]['url']) : 1;

            $open_img_class                 = ! empty($basics[ 'button_open_img' ]['url']) && $panel_type === 'toggler' ? ' has-img-open' : '';
            $the_same_img                   = $open_close_img_the_same === 0 ? ' close-img-thesame' : '';
            $close_img_class                = ! empty($basics[ 'button_close_img' ]['url']) && $open_close_img_the_same !== 0 ? ' has-img-close' : $the_same_img;
            $toggler_img_classes            = $open_img_class .$close_img_class;

            $open_img_alt                   = ! empty($basics[ 'button_open_img' ]['alt'])     ? $basics[ 'button_open_img' ]['alt']     : esc_html__('Open a panel', 'maxboxy');
            $close_img_alt                  = ! empty($basics[ 'button_close_img' ]['alt'])    ? $basics[ 'button_close_img' ]['alt']    : esc_html__('Close a panel', 'maxboxy');
            $open_img_width                 = ! empty($basics[ 'button_open_img' ]['width'])   ? $basics[ 'button_open_img' ]['width']   : 100;
            $close_img_width                = ! empty($basics[ 'button_close_img' ]['width'])  ? $basics[ 'button_close_img' ]['width']  : 100;
            $open_img_height                = ! empty($basics[ 'button_open_img' ]['height'])  ? $basics[ 'button_open_img' ]['height']  : 100;
            $close_img_height               = ! empty($basics[ 'button_close_img' ]['height']) ? $basics[ 'button_close_img' ]['height'] : 100;

            $_escaped_trig_img_open         = ! empty($open_img_class)  ? '<img src="' .esc_url($basics[ 'button_open_img' ]['url']) .'" class="trig-img-open" width="' .esc_attr($open_img_width) .'" height="' .esc_attr($open_img_height) .'" alt="' .esc_attr($open_img_alt) .'">'  : '';
            $_escaped_trig_img_close        = ! empty($close_img_class) && empty($the_same_img) && $unset_toggler === 'no' ? '<img src="' .esc_url($basics[ 'button_close_img' ]['url']) .'" class="trig-img-close" width="' .esc_attr($close_img_width) .'" height="' .esc_attr($close_img_height) .'" alt="' .esc_attr($close_img_alt) .'">' : '';

            // trigger animation
            $get_trigger_anim               = $unset_toggler === 'no' && ! empty($basics[ 'trigger_anim' ]) ? ' ' .$basics[ 'trigger_anim' ] : '';
            $get_anim_appear                = ! empty($basics[ 'trigger_anim_appear' ]) ? $basics[ 'trigger_anim_appear' ] : '';
            // Convert array to a string
            $anim_appear                    = ! empty($get_trigger_anim) && is_array($get_anim_appear) ? ' ' .implode(' ', $get_anim_appear) : '';
            $trigger_anim                   = $get_trigger_anim .$anim_appear;

            $anim_echo                      = isset($basics[ 'trigger_anim_echo_interval' ]) && is_numeric($basics[ 'trigger_anim_echo_interval' ]) ? abs($basics[ 'trigger_anim_echo_interval' ]) : 15; // default 15s
            $_escaped_anim_echo_data        = ! empty($trigger_anim) && in_array('anim-echo', $get_anim_appear) ? ' data-anim-echo="'  .esc_attr($anim_echo) .'"' : '';

            // Rotator - on time span
            $rotator_on                     = isset($basics[ 'rotator_on' ]) && is_numeric($basics[ 'rotator_on' ]) ? abs($basics[ 'rotator_on' ]) : 5; // default 5s
            $_escaped_rotator_on_data       = ' data-rotator-on="'  .esc_attr($rotator_on) .'"';

            // Rotator - off time span
            $rotator_off                    = isset($basics[ 'rotator_off' ]) && is_numeric($basics[ 'rotator_off' ]) ? abs($basics[ 'rotator_off' ]) : 10; // default 10s
            $_escaped_rotator_off_data      = ' data-rotator-off="'  .esc_attr($rotator_off) .'"';

            // Rotator - pause on user's closing
            $rotator_close_pause            = isset($basics[ 'rotator_close_pause' ]) && is_numeric($basics[ 'rotator_close_pause' ]) ? abs($basics[ 'rotator_close_pause' ]) : '';
            $_escaped_rota_close_pause_data = $panel_type === 'closer' && ! empty($rotator_close_pause) ? ' data-rotator-close-pause="'  .esc_attr($rotator_close_pause) .'"' : '';

            $_escaped_rotator_time_data     = $rotator === true ? $_escaped_rotator_on_data .$_escaped_rotator_off_data .$_escaped_rota_close_pause_data : '';
            $rotator_repeat                 = $rotator === true && ! empty($basics[ 'rotator_repeat' ]) ? ' rotator-repeat' : '';

            // additional message for the trigger button
            $trigger_add_message            = $panel_type === 'toggler' && ! empty($basics[ 'trigger_additional_message' ]) ? $basics[ 'trigger_additional_message' ] : '';
            $trigger_add_message_class      = $panel_type === 'toggler' && ! empty($basics[ 'trigger_additional_message' ]) ? ' has-additional-message' : '';
            $rotator_repeat                 = $rotator === true && ! empty($basics[ 'rotator_repeat' ]) ? ' rotator-repeat' : '';

            // additional message for the panel
            $panel_add_lable            = ! empty($basics[ 'panel_additional_lable' ]) ? $basics[ 'panel_additional_lable' ] : '';
            $panel_add_lable_class      = ! empty($basics[ 'panel_additional_lable' ]) ? ' has-additional-label' : '';

            /*
             * Additional classes - the field is in the group (i.e. in tab),
             * so we need to sanitize it here.
             */
            $add_classes = ! empty($basics[ 'add_classes' ]) ? ' ' .sanitize_text_field($basics[ 'add_classes' ]) : '';

             /*
              * Sizes
              */
            $width                          = ! empty($basics[ 'size_1' ][ 'width' ]) ? $basics[ 'size_1' ][ 'width' ] : '';
            $height                         = isset($basics[ 'height_100' ]) && $basics[ 'height_100' ] === 'yes' ? true : false;
            $unit                           = ! empty($basics[ 'size_1' ][ 'unit' ]) ? $basics[ 'size_1' ][ 'unit' ] : '';
            $_escaped_width_data            = ! empty($width)  ? ' data-panel-width="'  .esc_attr($width)  .esc_attr($unit) .'"' : '';
            $_escaped_height_data           = $height === true ? ' data-panel-height="100%"'  : '';

            $width_large                    = ! empty($basics[ 'size_2' ][ 'width' ])  ?  $basics[ 'size_2' ][ 'width' ] : '';
            $height_large                   = isset($basics[ 'height_100_2' ]) && $basics[ 'height_100_2' ] === 'yes' ? '100%' : false;
            $height_large                   = $height === true && isset($basics[ 'height_100_2' ]) && $basics[ 'height_100_2' ] === 'no' ? 'auto' : $height_large;
            $unit_large                     = ! empty($basics[ 'size_2' ][ 'unit' ])   ?  $basics[ 'size_2' ][ 'unit' ] : '';
            $_escaped_width_data_large      = ! empty($width_large)   ? ' data-panel-large-width="'.esc_attr($width_large).esc_attr($unit_large) .'"' : '';
            $_escaped_height_data_large     = $height_large !== false ? ' data-panel-large-height="' .esc_attr($height_large) .'"' :'';

            $_escaped_panel_data            = $_escaped_width_data .$_escaped_height_data .$_escaped_width_data_large .$_escaped_height_data_large;
            $panel_size_class               = ! empty($_escaped_panel_data) ? ' with-size' : '';

            // if size isn't 100 panel alignment is relevant for the injectany box
            $injectany_align                = isset($basics[ 'box_align' ]) ? ' align-' .$basics[ 'box_align' ] : '';

            // panel's padding
            $padding_unit                   = isset($basics[ 'panel_padding' ][ 'unit' ]) ? $basics[ 'panel_padding' ][ 'unit' ] : '';

            $get_pad_top                    = isset($basics[ 'panel_padding' ][ 'top' ]) && is_numeric($basics[ 'panel_padding' ][ 'top' ]) ? abs($basics[ 'panel_padding' ][ 'top' ])   : '';
            $panel_padding                  = ! empty($get_pad_top) ? 'padding-top: ' .$get_pad_top .$padding_unit .';' : '';
            
            $get_pad_left                   = isset($basics[ 'panel_padding' ][ 'left' ]) && is_numeric($basics[ 'panel_padding' ][ 'left' ]) ? abs($basics[ 'panel_padding' ][ 'left' ])  : '';
            $panel_padding                 .= ! empty($get_pad_left) ? 'padding-left: ' .$get_pad_left .$padding_unit .';' : '';
            
            $get_pad_right                  = isset($basics[ 'panel_padding' ][ 'right' ]) && is_numeric($basics[ 'panel_padding' ][ 'right' ]) ? abs($basics[ 'panel_padding' ][ 'right' ]) : '';
            $panel_padding                 .= ! empty($get_pad_right) ? 'padding-right: ' .$get_pad_right .$padding_unit .';' : '';
            
            $get_pad_bottom                 = isset($basics[ 'panel_padding' ][ 'bottom' ]) && is_numeric($basics[ 'panel_padding' ][ 'bottom' ]) ? abs($basics[ 'panel_padding' ][ 'bottom' ]): '';
            $panel_padding                 .= ! empty($get_pad_bottom) ? 'padding-bottom: ' .$get_pad_bottom .$padding_unit .';' : '';

            // panel's border
            $border                         = isset($basics[ 'panel_border' ]) ?   $basics[ 'panel_border' ] : '';
            $border_style                   = isset($border[ 'style' ])        ?   ' ' .$border[ 'style' ] : '';
            $border_color                   = ! empty($border[ 'color' ])      ?   ' ' .$border[ 'color' ] : '';
            $border_top                     = isset($border[ 'top' ]) && is_numeric($border[ 'top' ])       ? 'border-top:' .abs($border[ 'top' ])       .'px' .$border_style .$border_color .';' : '';
            $border_right                   = isset($border[ 'right' ]) && is_numeric($border[ 'right' ])   ? 'border-right:' .abs($border[ 'right' ])   .'px' .$border_style .$border_color .';' : '';
            $border_bottom                  = isset($border[ 'bottom' ]) && is_numeric($border[ 'bottom' ]) ? 'border-bottom:' .abs($border[ 'bottom' ]) .'px' .$border_style .$border_color .';' : '';
            $border_left                    = isset($border[ 'left' ]) && is_numeric($border[ 'left' ])     ? 'border-left:' .abs($border[ 'left' ])     .'px' .$border_style .$border_color .';' : '';

            $panel_border                   = $border_top .$border_right .$border_bottom .$border_left;

            // panel's border
            $border_radius                  = isset($basics[ 'panel_border_radius' ]) ?   $basics[ 'panel_border_radius' ] : '';
            $border_radius_unit             = isset($border_radius[ 'unit' ])        ?   $border_radius[ 'unit' ] : '';
            $border_radius_top_left         = isset($border_radius[ 'top' ]) && is_numeric($border_radius[ 'top' ])       ? 'border-top-left-radius:' .abs($border_radius[ 'top' ])        .$border_radius_unit .';' : '';
            $border_radius_top_right        = isset($border_radius[ 'right' ]) && is_numeric($border_radius[ 'right' ])   ? 'border-top-right-radius:' .abs($border_radius[ 'right' ])     .$border_radius_unit .';' : '';
            $border_radius_bottom_left      = isset($border_radius[ 'bottom' ]) && is_numeric($border_radius[ 'bottom' ]) ? 'border-bottom-left-radius:' .abs($border_radius[ 'bottom' ])  .$border_radius_unit .';' : '';
            $border_radius_bottom_right     = isset($border_radius[ 'left' ]) && is_numeric($border_radius[ 'left' ])     ? 'border-bottom-right-radius:' .abs($border_radius[ 'left' ])   .$border_radius_unit .';' : ''; // using spacing field, that's why 'left' is usedhere

            $panel_border_radius            = $border_radius_top_left .$border_radius_top_right .$border_radius_bottom_left .$border_radius_bottom_right;


            // Closer/toggler styling

            $get_closer_style               = ! empty($basics[ 'closer_styling' ]) ? $basics[ 'closer_styling' ]  : '';
            // convert the array to a string
            $check_closer_style             = is_array($get_closer_style)   ?   implode(' ', $get_closer_style)   : '';
            // prepend a space before the output, so it adds correctly to the existing classes ...$panel_type set on the Basic plugin
            $toggler_styling                = $unset_toggler === 'no' && ! empty($check_closer_style)
                                            ? ' ' .$check_closer_style : '';

            // check is the style 'inside'. We'll need this to dismiss the '-rev' output beneath when it's 'inside'
            $is_inside                      = is_array($get_closer_style) && in_array('inside', $get_closer_style) ? true : false;

            /**
             * Flex reverse when $is_inside !== true: 3, 4, 7, 8, 9 , 11 ? '-rev' : ''
             * Flex reverse when $is_inside === true: 1, 2, 5, 6, 10 , 12 ? '-rev' : ''
             *
             * Column ($get_direction): 5, 6, 7, 8 11, 12   ? 'column' : 'row'
             *
             * Align-center: 9, 10, 11, 12 ? 'align-center' : ''
             * align-end: 2, 4, 6, 8       ? 'align-end' : ''
             */

            $reverse                        = $unset_toggler !== true && $is_inside !== true && isset($basics[ 'toggler_pos' ]) && ($basics[ 'toggler_pos' ] === '3' || $basics[ 'toggler_pos' ] === '4' || $basics[ 'toggler_pos' ] === '7' || $basics[ 'toggler_pos' ] === '8' || $basics[ 'toggler_pos' ] === '9' || $basics[ 'toggler_pos' ] === '11') ? '-rev' : '';
            $reverse                        = $unset_toggler !== true && $is_inside === true && isset($basics[ 'toggler_pos' ]) && ($basics[ 'toggler_pos' ] === '1' || $basics[ 'toggler_pos' ] === '2' || $basics[ 'toggler_pos' ] === '5' || $basics[ 'toggler_pos' ] === '6' || $basics[ 'toggler_pos' ] === '10' || $basics[ 'toggler_pos' ] === '12') ? '-rev' : $reverse;

            $get_direction                  = $unset_toggler !== true && isset($basics[ 'toggler_pos' ]) && ($basics[ 'toggler_pos' ] === '5' || $basics[ 'toggler_pos' ] === '6' || $basics[ 'toggler_pos' ] === '7' || $basics[ 'toggler_pos' ] === '8' || $basics[ 'toggler_pos' ] === '11' || $basics[ 'toggler_pos' ] === '12') ? 'column' : 'row';
            $direction                      = !empty($get_direction) ? ' dir-' .$get_direction .$reverse : '';

            $closer_align_center            = $unset_toggler !== true && isset($basics[ 'toggler_pos' ]) && ($basics[ 'toggler_pos' ] === '9' || $basics[ 'toggler_pos' ] === '10' || $basics[ 'toggler_pos' ] === '11' || $basics[ 'toggler_pos' ] === '12') ? ' align-center' : '';
            $closer_align_end               = $unset_toggler !== true && isset($basics[ 'toggler_pos' ]) && ($basics[ 'toggler_pos' ] === '2' || $basics[ 'toggler_pos' ] === '4' || $basics[ 'toggler_pos' ] === '6' || $basics[ 'toggler_pos' ] === '8') ? ' align-end' : '';
            $closer_align                   = !empty($closer_align_center) ? $closer_align_center : ' align-start';
            $closer_align                   = !empty($closer_align_end)    ? $closer_align_end : $closer_align;

            $closer_size                    = $unset_toggler !== true && isset($basics[ 'closer_size' ]) && $basics[ 'closer_size' ] !== 'normal' ? ' ' .$basics[ 'closer_size' ] : '';

            // trigger's margin
            $trig_margin_unit               = isset($basics[ 'trigger_margin' ][ 'unit' ])     ? $basics[ 'trigger_margin' ][ 'unit' ] : '';
            $trig_margin_unit_top           = ! empty($basics[ 'trigger_margin_unit_top' ])    ? $basics[ 'trigger_margin_unit_top' ]  : $trig_margin_unit;
            $trig_margin_unit_left          = ! empty($basics[ 'trigger_margin_unit_left' ])   ? $basics[ 'trigger_margin_unit_left' ]  : $trig_margin_unit;
            $trig_margin_unit_right         = ! empty($basics[ 'trigger_margin_unit_right' ])  ? $basics[ 'trigger_margin_unit_right' ]  : $trig_margin_unit;
            $trig_margin_unit_bottom        = ! empty($basics[ 'trigger_margin_unit_bottom' ]) ? $basics[ 'trigger_margin_unit_bottom' ]  : $trig_margin_unit;

            $trig_mar_top                   = isset($basics[ 'trigger_margin' ][ 'top' ]) && is_numeric($basics[ 'trigger_margin' ][ 'top' ]) ? $basics[ 'trigger_margin' ][ 'top' ]   : '';
            $trigger_margin                 = ! empty($trig_mar_top) ? 'margin-top: ' .$trig_mar_top .$trig_margin_unit_top .';' : '';
            
            $trig_mar_left                  = isset($basics[ 'trigger_margin' ][ 'left' ]) && is_numeric($basics[ 'trigger_margin' ][ 'left' ]) ? $basics[ 'trigger_margin' ][ 'left' ]  : '';
            $trigger_margin                .= ! empty($trig_mar_left) ? 'margin-left: ' .$trig_mar_left .$trig_margin_unit_left .';' : '';
            
            $trig_mar_right                 = isset($basics[ 'trigger_margin' ][ 'right' ]) && is_numeric($basics[ 'trigger_margin' ][ 'right' ]) ? $basics[ 'trigger_margin' ][ 'right' ] : '';
            $trigger_margin                .= ! empty($trig_mar_right) ? 'margin-right: ' .$trig_mar_right .$trig_margin_unit_right .';' : '';
            
            $trig_mar_bottom                = isset($basics[ 'trigger_margin' ][ 'bottom' ]) && is_numeric($basics[ 'trigger_margin' ][ 'bottom' ]) ? $basics[ 'trigger_margin' ][ 'bottom' ] : '';
            $trigger_margin                .= ! empty($trig_mar_bottom) ? 'margin-bottom: ' .$trig_mar_bottom .$trig_margin_unit_bottom .';' : '';

            $no_margin_closer               = $panel_type === 'toggler' && ! empty($basics[ 'eliminate_margin_closer' ]) ? ' closer-no-margin' : '';

            /*
             * Pick the styling from diffrent vars
             */
            $_escaped_trig_style            = ! empty($trig_bg) || ! empty($trig_color) || !empty($trigger_margin)
                                            ? ' style="' .esc_attr($trig_bg) .esc_attr($trig_color) .esc_attr($trigger_margin) .'"' : '';

            $_escaped_trig_message_style    = ! empty($trig_bg) || ! empty($trig_color)
                                            ? ' style="' .esc_attr($trig_bg) .esc_attr($trig_color) .'"' : '';

            $_escaped_panel_content_style   = ! empty($panel_padding) || ! empty($panel_border) || ! empty($panel_border_raus) || ! empty($set_panel_bg) || ! empty($panel_color)
                                            ? ' style="' .esc_attr($panel_padding) .esc_attr($panel_border) .esc_attr($panel_border_radius) .esc_attr($set_panel_bg) .esc_attr($panel_color) .'"' : '';

            // gather arguments
            $args = array(
                'type'                       => $panel_type,
                // classes:
                'strain'                     => $panel_strain,
                'style'                      => $showing_style,
                'roles'                      => $panel_roles,
                'rotator_repeat'             => $rotator_repeat,
                'trig_class'                 => $trig_class,
                'add_classes'                => $add_classes,
                'panel_size'                 => $panel_size_class,
                'direction'                  => $direction,
                'closer_align'               => $closer_align,
                'closer_size'                => $closer_size,
                'toggler_styling'            => $toggler_styling,
                'toggler_start_class'        => $toggler_start_class,
                'trigger_add_message_class'  => $trigger_add_message_class,
                'toggler_svg_classes'        => $toggler_svg_classes,
                'toggler_img_classes'        => $toggler_img_classes,
                'trigger_icon_classes'       => $trigger_icon_classes,
                'trigger_anim'               => $trigger_anim,
                'unset_toggler_class'        => $unset_toggler_class,
                'panel_add_lable_class'      => $panel_add_lable_class,
                'injectany_align'            => $injectany_align,
                'sticky'                     => $sticky,
                'no_margin_closer'           => $no_margin_closer,
                // data:
                'anim_echo_time'             => $_escaped_anim_echo_data,
                'rotator_time'               => $_escaped_rotator_time_data,
                'wrap_style'                 => $_escaped_panel_wrap_style,
                'panel_style'                => $_escaped_panel_data,
                'content_style'              => $_escaped_panel_content_style,
                'trig_style'                 => $_escaped_trig_style,
                'trig_message_style'         => $_escaped_trig_message_style,
                'toggler_data'               => $_escaped_toggler_data,
                'trigger_add_message'        => $trigger_add_message,
                'trig_svg_open'              => $_safe_trig_svg_open,
                'trig_svg_close'             => $_safe_trig_svg_close,
                'trig_img_open'              => $_escaped_trig_img_open,
                'trig_img_close'             => $_escaped_trig_img_close,
                'panel_add_lable'            => $panel_add_lable,
                // else:
                'unset_toggler'              => $unset_toggler,
                'toggler_start_title'        => $toggler_start_title,
                'use_overlay'                => $use_overlay,
            );

            return $args;

        }


        /**
         * Conversions options, i.e. goals, tracking.
         *
         * @param int $get_id Receive the id of the panel.
         * 
         * @return array.
         */
        public static function conversions( $get_id )
        {

            $settings                       = get_post_meta($get_id, '_mb_maxboxy_conversion', true);
            $conversions                    = isset($settings[ 'box_options' ]) ?  $settings[ 'box_options' ]   : '';

            $goal                           = ! empty($conversions[ 'goal' ])                   ? $conversions[ 'goal' ]  : '';
            $goal_submit_check              = ! empty($conversions[ 'goal_form_submit' ])       ? $conversions[ 'goal_form_submit' ]  : '';
            $goal_click_target_attr         = ! empty($conversions[ 'goal_click_target_attr' ]) ? $conversions[ 'goal_click_target_attr' ]  : '';
            $set_goal_click_target_attr     = $goal_click_target_attr  === 'id'  ? '#' : '.'; // ID or class
            $goal_attr_value                = ! empty($conversions[ 'goal_attr_value' ])        ?   sanitize_html_class($conversions[ 'goal_attr_value' ])  : ''; // text field in a group - needs sanitization here

            $_escaped_goal_click_target     = $goal === 'click'  && ! empty($goal_attr_value)   ?   ' data-goal-target="'  .esc_attr($set_goal_click_target_attr) .esc_attr($goal_attr_value)  .'"'  : '';

            $_escaped_goal_form_has_class   = $goal === 'submit' && $goal_submit_check === 'form_has_class'   && ! empty($goal_attr_value) ? ' data-goal-form-hasclass="'   .esc_attr($goal_attr_value).'"' : '';
            $_escaped_goal_panel_find_class = $goal === 'submit' && $goal_submit_check === 'panel_find_class' && ! empty($goal_attr_value) ? ' data-goal-panel-findclass="' .esc_attr($goal_attr_value).'"' : '';

            $_escaped_goals                 = $_escaped_goal_click_target .$_escaped_goal_form_has_class .$_escaped_goal_panel_find_class;

            $goalset                        = ! empty($goa) ? ' goalset goal-' .$goal : '';

            $goal_after_banish              = ! empty($goa) && ! empty($conversions[ 'goal_after_banish' ]) ? ' goal-after-banish' : '';

            $track_loggedin_users           = ! empty($conversions[ 'track_loggedin_users' ]) ? true : false;

            $args = array(
                'goalset'         => $goalset,
                 'banish'         => $goal_after_banish,
                 'goal_data'      => $_escaped_goals,
                 'track_loggedin' => $track_loggedin_users,
            );

            return $args;

        }


    } // end class

} // end class exists check
